/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 02884
 |        NATIONAL TREATMENT IMPROVEMENT EVALUATION STUDY (NTIES),
 |                               1992-1997
 |       (DATASET 0001: NTIES RESEARCH INTAKE QUESTIONNAIRE (NRIQ))
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\02884-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE r2ffffff  1='(1) SHORT TERM HOSPITAL' 2='(2) LONG TERM HOSPITAL'
                  3='(3) SHORT TERM RESIDENTIAL' 4='(4) LONG TERM RESIDENTIAL'
                  5='(5) OUTPATIENT METHADONE' 6='(6) AMBULATORY OUTPATIENT' ;
  VALUE r5m1ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ON OR BEFORE MARCH 8, 1994' 2='(2) AFTER MARCH 8, 1994' ;
  VALUE r15fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) ENGLISH' 1='(1) SPANISH' ;
  VALUE prgmtype  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) CRITICAL POPULATIONS' 2='(2) CORRECTIONAL SETTINGS'
                  3='(3) OFFENDERS' 4='(4) TARGET CITIES' 5='(5) JUSTICE'
                  6='(6) PUBLIC HOUSING' ;
  VALUE trtment   -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) HOSPITAL IN-PATIENT SHORT-TERM'
                  2='(2) HOSPITAL IN-PATIENT LONG-TERM'
                  3='(3) RESIDENTIAL SHORT-TERM' 4='(4) RESIDENTIAL LONG-TERM'
                  5='(5) OUT-PATIENT METHADONE' 6='(6) AMBULATORY OUT-PATIENT' ;
  VALUE trt2ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) SHORT-TERM RESIDENTIAL/IN-PATIENT'
                  2='(2) LONG-TERM RESIDENTIAL/IN-PATIENT'
                  3='(3) OUT-PATIENT METHADONE' 4='(4) AMBULATORY OUT-PATIENT' ;
  VALUE prg2ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) AJJ/ PH' 2='(2) CRIMINAL JUSTICE' 3='(3) TARGET CITIES' ;
  VALUE cell      -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) CP/ SR' 2='(2) CP/ LR' 3='(3) CP/ OP' 4='(4) TC/ SR' 5='(5) TC/ LR'
                  6='(6) TC/ OP' 7='(7) CJ/ SR' 8='(8) CJ/ LR' 9='(9) CJ/ OP' 10='(10) METHADONE' ;
  VALUE cell2fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) METHADONE' 2='(2) NON-METHADONE OUT-PATIENT'
                  3='(3) SHORT-TERM RESIDENTIAL' 4='(4) LONG-TERM RESIDENTIAL'
                  5='(5) CORRECTIONAL SETTINGS' ;
  VALUE r17fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  2='(2) JAIL' 3='(3) PRISON' 4='(4) OTHER SITES' ;
  VALUE r19fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r21fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  2='(2) 2 TO 6 DAYS' 3='(3) 1-4 WEEKS' 4='(4) 1-3 MONTHS'
                  5='(5) 4-12 MONTHS' 6='(6) MORE THAN 1 YEAR' ;
  VALUE r24m1fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r24m2fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r24m3fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r24m4fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r24m6fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r24m7fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 2='(2) NO' ;
  VALUE r24m8fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r24m9fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r24m10ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r24m11ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r24m12ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r24m13ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r24m14ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r24m15ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r24m16ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r24m17ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r24m18ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r24m19ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r24m21ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r24m22ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r25m1fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r25m2fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r25m3fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r25m4fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r27fffff  -9='(-9) LEGITIMATE SKIP' ;
  VALUE r29fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) MALE' 2='(2) FEMALE' ;
  VALUE r34fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  17='(17) 17 OR YOUNGER' 51='(51) 51 OR OLDER' ;
  VALUE r35fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' ;
  VALUE r39fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r41fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r42fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r44m1fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONHISPANIC BLACK' 2='(2) HISPANIC' 3='(3) NONHISPANIC NONBLACK' ;
  VALUE r46fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r47fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) SPANISH ONLY' 2='(2) OTHER LANGUAGE(S) ONLY'
                  3='(3) BOTH SPANISH AND OTHER LANGUAGE(S)' ;
  VALUE r50fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ENGLISH' 2='(2) SPANISH' 3='(3) OTHER LANGUAGE(S)'
                  4='(4) PREFERENCE DEPENDS ON SITUATION' ;
  VALUE r53fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) EXCELLENT?' 2='(2) GOOD?' 3='(3) FAIR?' 4='(4) POOR?' ;
  VALUE r55fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r56m1fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r56m2fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r56m3fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r56m4fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r56m5fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r56m6fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r56m8fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r56m9fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r58fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  6='(6) 6TH GRADE OR LOWER' 7='(7) 7TH GRADE' 8='(8) 8TH GRADE'
                  9='(9) 9TH GRADE' 10='(10) 10TH GRADE' 11='(11) 11TH GRADE'
                  12='(12) 12TH GRADE' 13='(13) 1 YEAR COLLEGE/TECHNICAL SCHOOL'
                  14='(14) 2 YEARS COLLEGE/TECHNICAL SCHOOL'
                  15='(15) 3 YEARS COLLEGE/TECHNICAL SCHOOL'
                  16='(16) 4 YEARS COLLEGE/TECHNICAL SCHOOL OR MORE' ;
  VALUE r61fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r62fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) HIGH SCHOOL DIPLOMA' 2='(2) GED CERTIFICATE' ;
  VALUE r64fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r67fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r71fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) BETTER THAN AVERAGE' 2='(2) AVERAGE' 3='(3) NOT SO GOOD' ;
  VALUE r72fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r74fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r76fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  7='(7) 7 OR YOUNGER' 8='(8) 8' 9='(9) 9' 10='(10) 10' 11='(11) 11' 12='(12) 12'
                  13='(13) 13' 14='(14) 14' 15='(15) 15' 16='(16) 16' 17='(17) 17' 18='(18) 18 OR OLDER' ;
  VALUE r77fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r84m1fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r84m2fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r84m3fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r84m4fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r84m5fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r84m6fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r84m7fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r84m8fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r84m10ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r84m12ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r90m1fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r90m2fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r90m3fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r90m4fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r90m5fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r90m6fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r90m7fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r90m8fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r90m9fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r90m10ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r90m11ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r91fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NOT AT ALL' 2='(2) SOMEWHAT' 3='(3) VERY MUCH'
                  4='(4) R DOES NOT USE DRUGS OTHER THAN ALCOHOL' ;
  VALUE r92fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY IMPORTANT' 2='(2) SOMEWHAT IMPORTANT'
                  3='(3) NOT AT ALL IMPORTANT' ;
  VALUE r93fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 1 DAY OR LESS' 2='(2) 2-6 DAYS' 3='(3) 1-3 WEEKS' 4='(4) 1-3 MONTHS'
                  5='(5) 4-12 MONTHS' 6='(6) MORE THAN 1 YEAR' ;
  VALUE r97fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r99fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r100m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r100m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r100m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r100m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r100m5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r100m6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r108a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE r108a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE r108a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE r108a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE r108a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE r108a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE r108a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE r108a8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE r108a9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE r108a10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE r108a11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE r108a12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE r113m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r113m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r113m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r113m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r113m5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r113m6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r113m7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r113m8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r113m9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r113m10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r113m11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r113m12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r113m13f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r113m14f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r114m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r114m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r114m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r114m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r114m5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r114m6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r114m7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r114m8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r116a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  9='(9) 9 OR YOUNGER' 18='(18) 18 OR OLDER' ;
  VALUE r117a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r120a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN PAST MONTH' 2='(2) 1-12 MONTHS AGO'
                  3='(3) MORE THAN 12 MONTHS AGO' ;
  VALUE r122a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE r116a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  7='(7) 7 OR YOUNGER' 21='(21) 21 OR OLDER' ;
  VALUE r117a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r120a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN PAST MONTH' 2='(2) 1-12 MONTHS AGO'
                  3='(3) MORE THAN 12 MONTHS AGO' ;
  VALUE r122a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE r123a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE r116a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  14='(14) 14 OR YOUNGER' 40='(40) 40 OR OLDER' ;
  VALUE r117a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r118a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r119a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-12 MONTHS AGO'
                  3='(3) MORE THAN 12 MONTHS AGO' ;
  VALUE r120a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN PAST MONTH' 2='(2) 1-12 MONTHS AGO'
                  3='(3) MORE THAN 12 MONTHS AGO' ;
  VALUE r122a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE r123a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE r116a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  12='(12) 12 OR YOUNGER' 35='(35) 35 OR OLDER' ;
  VALUE r117a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r118a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r119a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-12 MONTHS AGO'
                  3='(3) MORE THAN 12 MONTHS AGO' ;
  VALUE r120a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN PAST MONTH' 2='(2) 1-12 MONTHS AGO'
                  3='(3) MORE THAN 12 MONTHS AGO' ;
  VALUE r122a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE r123a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE r116a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  13='(13) 13 OR YOUNGER' 20='(20) 20 OR OLDER' ;
  VALUE r117a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r120a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN PAST MONTH' 2='(2) 1-12 MONTHS AGO'
                  3='(3) MORE THAN 12 MONTHS AGO' ;
  VALUE r122a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE r116a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  12='(12) 12 OR YOUNGER' 22='(22) 22 OR OLDER' ;
  VALUE r117a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r120a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN PAST MONTH' 2='(2) 1-12 MONTHS AGO'
                  3='(3) MORE THAN 12 MONTHS AGO' ;
  VALUE r122a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE r116a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  13='(13) 13 OR YOUNGER' 28='(28) 28 OR OLDER' ;
  VALUE r117a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r120a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN PAST MONTH' 2='(2) 1-12 MONTHS AGO'
                  3='(3) MORE THAN 12 MONTHS AGO' ;
  VALUE r122a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE r123a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE r116a8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 16 OR YOUNGER' 2='(2) 17-20' 3='(3) 21-25' 4='(4) 26 OR OLDER' ;
  VALUE r117a8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r120a8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN PAST MONTH' 2='(2) 1-12 MONTHS AGO'
                  3='(3) MORE THAN 12 MONTHS AGO' ;
  VALUE r122a8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE r116a9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  13='(13) 13 OR YOUNGER' 22='(22) 22 OR OLDER' ;
  VALUE r117a9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r120a9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN PAST MONTH' 2='(2) 1-12 MONTHS AGO'
                  3='(3) MORE THAN 12 MONTHS AGO' ;
  VALUE r122a9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE r123a9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE r116a10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  12='(12) 12 OR YOUNGER' 24='(24) 24 OR OLDER' ;
  VALUE r117a10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r120a10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN PAST MONTH' 2='(2) 1-12 MONTHS AGO'
                  3='(3) MORE THAN 12 MONTHS AGO' ;
  VALUE r122a10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE r123a10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE r116a11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  12='(12) 12 OR YOUNGER' 22='(22) 22 OR OLDER' ;
  VALUE r117a11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r120a11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN PAST MONTH' 2='(2) 1-12 MONTHS AGO'
                  3='(3) MORE THAN 12 MONTHS AGO' ;
  VALUE r122a11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE r123a11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE r116a12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 16 OR YOUNGER' 2='(2) 17-20' 3='(3) 21-25' 4='(4) 26 OR OLDER' ;
  VALUE r117a12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r120a12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN PAST MONTH' 2='(2) 1-12 MONTHS AGO'
                  3='(3) MORE THAN 12 MONTHS AGO' ;
  VALUE r122a12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE r124ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r125ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-12 MONTHS AGO'
                  3='(3) MORE THAN 12 MONTHS AGO' ;
  VALUE r126ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE TIME' 2='(2) MORE THAN ONE TIME' ;
  VALUE r127ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NOTHING' 1='(1) 1-20' 2='(2) 21-100' 3='(3) 101-200' 4='(4) 201-300'
                  5='(5) 301-400' 6='(6) 401-500' 7='(7) 501-600' 8='(8) 601-700' 9='(9) 701-800'
                  10='(10) 801-900' 11='(11) 901-1000' 12='(12) 1001-2000' 13='(13) 2001-3000'
                  14='(14) 5000' ;
  VALUE r128ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r129ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) SKIP IF YES TO R128' ;
  VALUE r130ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN PAST 30 DAYS' 2='(2) AGO' 3='(3) MORE THAN 12 MONTHS AGO' ;
  VALUE r131ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE r132ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r133ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN PAST 30 DAYS' 2='(2) 31 DAYS AGO TO 12 MONTHS AGO'
                  3='(3) MORE THAN 12 MONTHS AGO' ;
  VALUE r135ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NEVER' 2='(2) LESS THAN HALF OF THE TIME'
                  3='(3) HALF OF THE TIME' 4='(4) MORE THAN HALF OF THE TIME'
                  5='(5) EVERY TIME' ;
  VALUE r136ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NEVER' 2='(2) LESS THAN HALF OF THE TIME'
                  3='(3) HALF OF THE TIME' 4='(4) MORE THAN HALF OF THE TIME'
                  5='(5) EVERY TIME' ;
  VALUE r137ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NEVER' 2='(2) LESS THAN HALF OF THE TIME'
                  3='(3) HALF OF THE TIME' 4='(4) MORE THAN HALF OF THE TIME'
                  5='(5) EVERY TIME' ;
  VALUE r138ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  2='(2) ONE DAY' 3='(3) 2-5 DAYS' 4='(4) 6-10 DAYS' 5='(5) 11-20 DAYS'
                  6='(6) 21 DAYS OR MORE' ;
  VALUE r139ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r140ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE DAY' 3='(3) 2-5 DAYS' 4='(4) 6-10 DAYS'
                  5='(5) 11-20 DAYS' 6='(6) 21 DAYS OR MORE' ;
  VALUE r142a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE DAY' 3='(3) 2-5 DAYS' 4='(4) 6-10 DAYS'
                  5='(5) 11-20 DAYS' 6='(6) 21 DAYS OR MORE' ;
  VALUE r143a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 1='(1) 1'
                  2='(2) 2' 3='(3) 3' 4='(4) 4' 5='(5) 5' 6='(6) 6' 9='(9) 7-11' 12='(12) 12' 18='(18) 13-22'
                  24='(24) 24' 40='(40) MORE THAN 25' ;
  VALUE r144a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) CANS' 2='(2) BOTTLES' 3='(3) GLASSES' 4='(4) QUARTS' 5='(5) PINTS'
                  10='(10) OTHER' ;
  VALUE r147a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  8='(8) 2-10' 12='(12) 12' 16='(16) 14-24' 40='(40) 32-80' ;
  VALUE r142a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE DAY' 3='(3) 2-5 DAYS' 4='(4) 6-10 DAYS'
                  5='(5) 11-20 DAYS' 6='(6) 21 DAYS OR MORE' ;
  VALUE r143a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 1='(1) 1'
                  2='(2) 2' 3='(3) 3' 4='(4) 4' 8='(8) 5 OR MORE' ;
  VALUE r144a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  2='(2) BOTTLES' 3='(3) GLASSES' 6='(6) FIFTHS' 10='(10) OTHER' ;
  VALUE r147a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  6='(6) 1-8' 12='(12) 9-15' 16='(16) 16' 32='(32) 20-64' ;
  VALUE r142a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' ;
  VALUE r143a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 1='(1) 1'
                  2='(2) 2' 3='(3) 3' 4='(4) 4' 6='(6) 5-10' 20='(20) 11 OR MORE' ;
  VALUE r144a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  4='(4) QUARTS' 5='(5) PINTS' 6='(6) FIFTHS' 7='(7) 1/2 PINTS' 8='(8) SHOTS'
                  9='(9) DRINKS' 10='(10) OTHER' ;
  VALUE r155ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE DAY' 3='(3) 2-5 DAYS' 4='(4) 6-10 DAYS'
                  5='(5) 11-20 DAYS' 6='(6) 21 DAYS OR MORE' ;
  VALUE r156ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE TIME' 3='(3) 2-5 TIMES' 4='(4) 6-20 TIMES'
                  5='(5) 21-100 TIMES' 6='(6) MORE THAN 100 TIMES' ;
  VALUE r157ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r159ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r160ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r161ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NOT AT ALL' 2='(2) SOMEWHAT' 3='(3) VERY MUCH' ;
  VALUE r162ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY IMPORTANT' 2='(2) SOMEWHAT IMPORTANT'
                  3='(3) NOT AT ALL IMPORTANT' ;
  VALUE r171ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r172ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r173ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r174ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r175ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r176ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r177ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r178ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r179ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r182a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r184a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r185a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' ;
  VALUE r182a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r184a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r185a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' ;
  VALUE r182a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r184a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r185a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' ;
  VALUE r182a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r185a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' ;
  VALUE r182a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r185a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1 OR MORE MONTHS' ;
  VALUE r182a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r185a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1 OR MORE MONTHS' ;
  VALUE r182a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r185a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' ;
  VALUE r182a8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r185a8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' ;
  VALUE r182a9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r185a9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' ;
  VALUE r187ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) RS OWN APARTMENT/HOUSE'
                  2='(2) SOMEONE ELSES APARTMENT/HOUSE'
                  3='(3) HOTEL,MOTEL,ROOMING/BOARDING HOUSE/DORM'
                  4='(4) HOMELESS SHELTER/ON STREET' 5='(5) OTHER TYPE OF SHELTER'
                  6='(6) HOSPITAL' 7='(7) DETENTION/ WORK RELEASE'
                  8='(8) OTHER TYPE OF GROUP HOME/TX CENTER' 9='(9) SOME OTHER PLACE' ;
  VALUE r189ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r190ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY IMPORTANT' 2='(2) SOMEWHAT IMPORTANT'
                  3='(3) NOT AT ALL IMPORTANT' ;
  VALUE r191ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' ;
  VALUE r192ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' ;
  VALUE r193ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r194ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r195ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  10='(10) 10 OR MORE' ;
  VALUE r198a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r198a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r198a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r198a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r198a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r200a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' ;
  VALUE r202a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r200a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' ;
  VALUE r202a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r200a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' ;
  VALUE r202a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r200a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' ;
  VALUE r202a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r200a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' ;
  VALUE r202a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r203ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r204m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r204m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r204m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r204m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r204m5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r204m6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r205ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r206m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r206m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r206m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r206m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r206m5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r206m6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r207ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r208m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r208m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r211ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r212ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r213ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r214ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r216ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 0='(0) 0'
                  1='(1) 1' 2='(2) 2' 3='(3) 3' 4='(4) 4 OR MORE' ;
  VALUE r218ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r219ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) R HAS CUSTODY OF ALL CHILDREN' ;
  VALUE r220ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) R DOESNT HAVE CUSTODY OF ANY CHILDREN' ;
  VALUE r221ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY EASY' 2='(2) SOMEWHAT EASY' 3='(3) SOMEWHAT DIFFICULT'
                  4='(4) VERY DIFFICULT' 5='(5) NEVER NEED TO GET CHILD CARE' ;
  VALUE r222ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r223ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r225ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r226ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN ONE MONTH' 2='(2) 1-12 MONTHS'
                  3='(3) MORE THAN 12 MONTHS' ;
  VALUE r227ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 0='(0) 0'
                  1='(1) 1' 2='(2) 2' 3='(3) 3' 4='(4) 4' 5='(5) 5 OR MORE' ;
  VALUE r228ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r229ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r231ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  41='(41) 41 OR OLDER' 99='(99) NO ONE' ;
  VALUE r232ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  41='(41) 41 OR OLDER' 99='(99) NO ONE' ;
  VALUE r233ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  41='(41) 41 OR OLDER' 99='(99) NO ONE' ;
  VALUE r234ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r236ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  5='(5) 5 OR MORE' ;
  VALUE r237ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r238ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 1='(1) 1'
                  2='(2) 2' 3='(3) 3' 4='(4) 4-9' 5='(5) 10 OR MORE' ;
  VALUE r239ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r240ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r241ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r242ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE TIME' 2='(2) 2-5 TIMES' 3='(3) 6-10 TIMES' 4='(4) 11-20 TIMES'
                  5='(5) 21-100 TIMES' 6='(6) MORE THAN 100 TIMES' ;
  VALUE r244ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r245ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN PAST MONTH' 2='(2) 1-12 MONTHS AGO'
                  3='(3) MORE THAN 12 MONTHS AGO' ;
  VALUE r246ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r247ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r248ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY IMPORTANT' 2='(2) SOMEWHAT IMPORTANT'
                  3='(3) NOT AT ALL IMPORTANT' 4='(4) NEVER RAISED CHILDREN' ;
  VALUE r250ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY IMPORTANT' 2='(2) SOMEWHAT IMPORTANT'
                  3='(3) NOT AT ALL IMPORTANT' ;
  VALUE r251ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY IMPORTANT' 2='(2) SOMEWHAT IMPORTANT'
                  3='(3) NOT AT ALL IMPORTANT' ;
  VALUE r255ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r256ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r258ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 1='(1) 1'
                  2='(2) 2' 3='(3) 3' 4='(4) 4' 5='(5) 5' 6='(6) 6-9' 7='(7) 10 OR MORE' ;
  VALUE r259ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  15='(15) 15 OR YOUNGER' 40='(40) 40 OR OLDER'
                  999='(999) NO PRIOR TREATMENT' ;
  VALUE r260ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 WEEK' 2='(2) 1-2 WEEKS' 3='(3) 3-4 WEEKS'
                  4='(4) 1-6 MONTHS' 5='(5) 7-12 MONTHS' 6='(6) MORE THAN 12 MONTHS'
                  7='(7) NO PRIOR TREATMENT' ;
  VALUE r262ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) INPATIENT' 2='(2) RESIDENTIAL' 3='(3) OUTPATIENT' 4='(4) METHADONE'
                  5='(5) NO PRIOR TREATMENT' ;
  VALUE r263ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r264ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ENTER PROVIDER' 2='(2) NONE MENTIONED'
                  3='(3) NO PRIOR TREATMENT' ;
  VALUE r270m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NONE' 1='(1) 1' 2='(2) 2 OR MORE' ;
  VALUE r270m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NONE' 1='(1) 1' 2='(2) 2 OR MORE' ;
  VALUE r270m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NONE' 1='(1) 1' 2='(2) 2 OR MORE' ;
  VALUE r270m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NONE' 1='(1) 1' 2='(2) 2 OR MORE' ;
  VALUE r271ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r272m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r272m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r272m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r273ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 15 OR YOUNGER' 2='(2) 16-20' 3='(3) 21-25' 4='(4) 26-30' 5='(5) 31-35'
                  6='(6) 36-40' 7='(7) 41 OR OLDER' ;
  VALUE r274ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r275ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r276ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 15 OR YOUNGER' 2='(2) 16-20' 3='(3) 21-25' 4='(4) 26-30' 5='(5) 31-35'
                  6='(6) 36-40' 7='(7) 41 OR OLDER' ;
  VALUE r277ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 1='(1) 1'
                  2='(2) 2' 3='(3) 3' 4='(4) 4 OR MORE' ;
  VALUE r278ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r279ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r280ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r281ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) 1-5 TIMES' 3='(3) 6-10 TIMES' 4='(4) 11-30 TIMES'
                  5='(5) 31 TIMES OR MORE' ;
  VALUE r282ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r287ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r288ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r289ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) SOME' 3='(3) ALL' ;
  VALUE r290ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r291ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r292ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r293ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r294ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r295ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r296ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) SKIPPED R295 YES' ;
  VALUE r297ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) SOME' 3='(3) ALL' ;
  VALUE r298ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r299ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r300ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r301ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NO ATTEMPTS' ;
  VALUE r302ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) SOME' 3='(3) ALL' 4='(4) NO ATTEMPTS' ;
  VALUE r303ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r304ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) SOME' 3='(3) ALL' 4='(4) NO ATTEMPTS' ;
  VALUE r305ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) MADE ATTEMPTS (SEE R299)' ;
  VALUE r306ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) SOME' 3='(3) ALL' ;
  VALUE r307ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r308ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) SOME' ;
  VALUE r309ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) SOME' 3='(3) ALL' ;
  VALUE r310ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NOT AT ALL' 2='(2) SOMEWHAT' 3='(3) VERY MUCH' ;
  VALUE r311ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NOT AT ALL IMPORTANT' 2='(2) SOMEWHAT IMPORTANT'
                  3='(3) VERY IMPORTANT' ;
  VALUE r313a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY EASY' 2='(2) SOMEWHAT EASY' 3='(3) SOMEWHAT DIFFICULT'
                  4='(4) VERY DIFFICULT' ;
  VALUE r313a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY EASY' 2='(2) SOMEWHAT EASY' 3='(3) SOMEWHAT DIFFICULT'
                  4='(4) VERY DIFFICULT' ;
  VALUE r313a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY EASY' 2='(2) SOMEWHAT EASY' 3='(3) SOMEWHAT DIFFICULT'
                  4='(4) VERY DIFFICULT' ;
  VALUE r322ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r323ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r324ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r325ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r326ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r327ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r328ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r329ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r330ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r331ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r332ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r333ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r334ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r335ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r336ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r337ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r338ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r339ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r340ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r341ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r344a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  11='(11) 11 OR YOUNGER' 19='(19) 19 OR OLDER' ;
  VALUE r345a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-5' 3='(3) 6-20' 4='(4) 21-100' 5='(5) 100+' 6='(6) NONE' ;
  VALUE r344a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  11='(11) 11 OR YOUNGER' 30='(30) 30 OR OLDER' ;
  VALUE r345a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-5' 3='(3) 6-20' 4='(4) 21-100' 5='(5) 100+' 6='(6) NONE' ;
  VALUE r345a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-5' 3='(3) 6-20' 4='(4) 21-100' 5='(5) 100+' 6='(6) NONE' ;
  VALUE r345a10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-5' 3='(3) 6-20' 4='(4) 21-100' 5='(5) 100+' 6='(6) NONE' ;
  VALUE r344a11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 11 OR YOUNGER' 2='(2) 12-17' 3='(3) 18 OR OLDER' ;
  VALUE r345a11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-5' 3='(3) 6-20' 4='(4) 21-100' 5='(5) 100+' 6='(6) NONE' ;
  VALUE r344a12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 11 OR YOUNGER' 2='(2) 12-17' 3='(3) 18 OR OLDER' ;
  VALUE r345a12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-5' 3='(3) 6-20' 4='(4) 21-100' 5='(5) 100+' 6='(6) NONE' ;
  VALUE r344a15f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 11 OR YOUNGER' 2='(2) 12-17' 3='(3) 18 OR OLDER' ;
  VALUE r345a15f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-5' 3='(3) 6-20' 4='(4) 21-100' 5='(5) 100+' 6='(6) NONE' ;
  VALUE r345a16f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-5' 3='(3) 6-20' 4='(4) 21-100' 5='(5) 100+' 6='(6) NONE' ;
  VALUE r345a17f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-5' 3='(3) 6-20' 4='(4) 21-100' 5='(5) 100+' 6='(6) NONE' ;
  VALUE r344a18f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 11 OR YOUNGER' 2='(2) 12-17' 3='(3) 18 OR OLDER' ;
  VALUE r346ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a13f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a13f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a14f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a14f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a15f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a15f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a16f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a16f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a17f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a17f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a18f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a18f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a19f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a19f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a20f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a20f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r348a21f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r351a21f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r352ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 15 OR YOUNGER' 2='(2) 16-20' 3='(3) 21-25' 4='(4) 26 OR OLDER' ;
  VALUE r353ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 1-3 TIMES' 2='(2) 4-10 TIMES' 3='(3) 11 OR MORE TIMES' ;
  VALUE r354ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 1 TIME' 2='(2) 2-3 TIMES' 3='(3) 4-10 TIMES'
                  4='(4) 11 OR MORE TIMES' ;
  VALUE r357ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r358ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r359ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 1 DAY OR LESS' 2='(2) 2-6 DAYS' 3='(3) 1-4 WEEKS' 4='(4) 1-3 MONTHS'
                  5='(5) 4-12 MONTHS' 6='(6) MORE THAN 1 YEAR' ;
  VALUE r360ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r361ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) R 26 OR OLDER' ;
  VALUE r362ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) R 26 OR OLDER' ;
  VALUE r363ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r364ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r365ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r366ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r369ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 5 OR MORE TIMES PER WEEK' 2='(2) 2-4 TIMES PER WEEK'
                  3='(3) ONCE A WEEK' 4='(4) 2-3 TIMES A MONTH'
                  5='(5) ONCE A MONTH OR LESS' 6='(6) NOT UNDER SUPERVISION' ;
  VALUE r371ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r372ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r373ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r377ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r378m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r378m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r378m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r378m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r378m5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r378m6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r378m7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r378m8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r378m9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r378m10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r378m11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r378m12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r378m13f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r378m14f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r378m15f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r378m16f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r378m17f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r379ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  11='(11) 11 OR YOUNGER' 30='(30) 30 OR OLDER' ;
  VALUE r380ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r381ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r384a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  3='(3) SERVICE WORKER' 5='(5) SKILLED WORKER OR CRAFTSMEN'
                  14='(14) OTHER' 200='(200) NO CURRENT JOB' ;
  VALUE r385a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r388a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 1-20' 2='(2) 21-35' 3='(3) 36-45' 4='(4) 46 OR MORE' ;
  VALUE r389a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN ONE MONTH' 2='(2) 1-12 MONTHS'
                  3='(3) MORE THAN 12 MONTHS' ;
  VALUE r389a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN ONE MONTH' 2='(2) 1-12 MONTHS'
                  3='(3) MORE THAN 12 MONTHS' ;
  VALUE r391ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r392ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NO CURRENT JOB' ;
  VALUE r393ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NO CURRENT JOB' ;
  VALUE r397m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) CURRENTLY EMPLOYED F/T' ;
  VALUE r397m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) CURRENTLY EMPLOYED F/T' ;
  VALUE r397m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) CURRENTLY EMPLOYED F/T' ;
  VALUE r397m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) CURRENTLY EMPLOYED F/T' ;
  VALUE r397m5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) CURRENTLY EMPLOYED F/T' ;
  VALUE r397m6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) CURRENTLY EMPLOYED F/T' ;
  VALUE r397m7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) CURRENTLY EMPLOYED F/T' ;
  VALUE r397m8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) CURRENTLY EMPLOYED F/T' ;
  VALUE r397m9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) CURRENTLY EMPLOYED F/T' ;
  VALUE r397m10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) CURRENTLY EMPLOYED F/T' ;
  VALUE r397m11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) CURRENTLY EMPLOYED F/T' ;
  VALUE r399ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-6 MONTHS AGO'
                  3='(3) 7-12 MONTHS AGO' 4='(4) MORE THAN 12 MONTHS AGO'
                  5='(5) CURRENTLY WORKING' ;
  VALUE r400ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN ONE MONTH' 2='(2) 1-6 MONTHS' 3='(3) 7-12 MONTHS'
                  4='(4) MORE THAN 12 MONTHS' ;
  VALUE r401ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r403ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) CLERICAL WORKER' 2='(2) SALES WORKER' 3='(3) SERVICE WORKER'
                  4='(4) PRIVATE HOUSEHOLD WORKER'
                  5='(5) SKILLED WORKER OR CRAFTSMEN' 6='(6) LABORER'
                  7='(7) OPERATOR OR MACHINE OPERATOR'
                  8='(8) TRANSPORTATION EQUIPMENT OPERATOR' 9='(9) FARM LABORER'
                  10='(10) FARMER OR FARM MANAGER' 11='(11) MANAGER/ ADMINISTRATOR'
                  12='(12) LAY COUNSELOR' 13='(13) PROFESSIONAL/ TECHNICAL' 14='(14) OTHER'
                  15='(15) INTERVIEWER UNABLE TO CODE' ;
  VALUE r407m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 4.25 PER HOUR' 2='(2) 4.25-10.00 PER HOUR'
                  3='(3) MORE THAN $10.00 PER HOUR' ;
  VALUE r409ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) LESS THAN ONE MONTH' 3='(3) 1-3 MONTHS'
                  4='(4) 4-6 MONTHS' 5='(5) 7-9 MONTHS' 6='(6) 10-12 MONTHS' ;
  VALUE r411ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NOT AT ALL IMPORTANT' 2='(2) SOMEWHAT IMPORTANT'
                  3='(3) VERY IMPORTANT' ;
  VALUE r412ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r413ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN HALF' 2='(2) HALF OR MORE' 3='(3) ALL' ;
  VALUE r416a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r416a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r416a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r416a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r416a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r416a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r416a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r419m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) Male, $3000 or less' 2='(2) Male, 3001-$10000'
                  3='(3) Male, $10001 or more' 4='(4) Female, $3000 or less'
                  5='(5) Female, $3001 or more' ;
  VALUE r419m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) Male, $3000 or less' 2='(2) Male, $3001-$10000'
                  3='(3) Male, $10001 or more' 4='(4) Female, $3000 or less'
                  5='(5) Female, $3001 or more' ;
  VALUE r420ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NOT AT ALL IMPORTANT' 2='(2) SOMEWHAT IMPORTANT'
                  3='(3) VERY IMPORTANT' ;
  VALUE r423ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) EXCELLENT?' 2='(2) GOOD?' 3='(3) FAIR?' 4='(4) POOR?' ;
  VALUE r427a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r427a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r427a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r427a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r427a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r427a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r427a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r427a8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r427a9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r427a10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r428ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r429ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r431ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NOT AT ALL' 2='(2) SOMEWHAT' 3='(3) VERY MUCH' ;
  VALUE r436a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE' 3='(3) 2-9' 4='(4) 10-25' 5='(5) 26-100' 6='(6) 101-500'
                  7='(7) MORE THAN 500' ;
  VALUE r437a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NEVER' 2='(2) LESS THAN 1/2' 3='(3) HALF OF THE TIME'
                  4='(4) MORE THAN 1/2' 5='(5) EVERY TIME' 6='(6) NO SUCH PARTNERS' ;
  VALUE r436a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE' 3='(3) 2-9' 4='(4) 10-25' 5='(5) 26-100' 6='(6) 101-500'
                  7='(7) MORE THAN 500' ;
  VALUE r437a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NEVER' 2='(2) LESS THAN 1/2' 3='(3) HALF OF THE TIME'
                  4='(4) MORE THAN 1/2' 5='(5) EVERY TIME' 6='(6) NO SUCH PARTNERS' ;
  VALUE r436a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE OR MORE' ;
  VALUE r437a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NEVER' 2='(2) LESS THAN 1/2' 3='(3) HALF OF THE TIME'
                  4='(4) MORE THAN 1/2' 5='(5) EVERY TIME' 6='(6) NO SUCH PARTNERS' ;
  VALUE r436a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE OR MORE' ;
  VALUE r437a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NEVER' 2='(2) LESS THAN 1/2' 3='(3) HALF OF THE TIME'
                  4='(4) MORE THAN 1/2' 5='(5) EVERY TIME' 6='(6) NO SUCH PARTNERS' ;
  VALUE r436a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE' 3='(3) 2-9' 4='(4) 10-25' 5='(5) 26-100' ;
  VALUE r437a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NEVER' 2='(2) LESS THAN 1/2' 3='(3) HALF OF THE TIME'
                  4='(4) MORE THAN 1/2' 5='(5) EVERY TIME' 6='(6) NO SUCH PARTNERS' ;
  VALUE r439ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r440ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r441ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r442ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r443ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r444ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r445ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE TIME' 2='(2) 2-5 TIMES' 3='(3) 6-10 TIMES' 4='(4) 11-20 TIMES'
                  5='(5) 21-100 TIMES' 6='(6) MORE THAN 100 TIMES' ;
  VALUE r447ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r448ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE TIME' 2='(2) 2-5 TIMES' 3='(3) 6-10 TIMES' 4='(4) 11-20 TIMES'
                  5='(5) 21-100 TIMES' 6='(6) MORE THAN 100 TIMES' ;
  VALUE r449ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r450ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r451ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r452ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r454a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 1 TIME' 2='(2) 2-5 TIMES' 3='(3) 6-9 TIMES' 4='(4) 10 OR MORE TIMES' ;
  VALUE r456a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r455a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 1 TIME' 2='(2) 2-9 TIMES' 3='(3) 10 TIMES OR MORE' ;
  VALUE r456a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r455a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 1 TIME' 2='(2) 2-9 TIMES' 3='(3) 10 TIMES OR MORE' ;
  VALUE r456a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r457ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NOT AT ALL IMPORTANT' 2='(2) SOMEWHAT IMPORTANT'
                  3='(3) VERY IMPORTANT' ;
  VALUE r458ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r459m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r459m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r459m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r459m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r462m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r462m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r462m5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE r463ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE (MALE)'
                  -5='(-5) NEVER' -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSAL' 1='(1) YES' 2='(2) NO' ;
  VALUE r464ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE (MALE)'
                  -5='(-5) NEVER' -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSAL' 1='(1) 1' 2='(2) 2' 3='(3) 3' 4='(4) 4' 5='(5) 5' 6='(6) 6 OR MORE' ;
  VALUE r465ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NONE' 1='(1) 1' 2='(2) 2' 3='(3) 3' 4='(4) 4' 5='(5) 5' 6='(6) 6 OR MORE' ;
  VALUE r466ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN PAST MONTH' 2='(2) 1-12 MONTHS AGO'
                  3='(3) MORE THAN 12 MONTHS AGO' ;
  VALUE r467ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE (MALE)'
                  -5='(-5) NEVER' -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSAL' 1='(1) YES' 2='(2) NO' 3='(3) NO BIRTHS' ;
  VALUE r468ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE (MALE)'
                  -5='(-5) NEVER' -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSAL' 1='(1) YES' 2='(2) NO' 3='(3) NO BIRTHS' ;
  VALUE r469ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) HIV?' 2='(2) FOR HIV?' 3='(3) NO BIRTHS' ;
  VALUE r470ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE (MALE)'
                  -5='(-5) NEVER' -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSAL' 1='(1) YES' 2='(2) NO' ;
  VALUE r471ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) INCREASED' 2='(2) STAYED ABOUT THE SAME' 3='(3) DECREASED' ;
  VALUE r472ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE rtotans   -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' ;
  VALUE rtotref   -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' ;
  VALUE rtotdk    -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' ;
  VALUE afdrug1f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) COCAINE' 2='(2) HEROIN' 3='(3) ALCOHOL' 4='(4) MARIJUANA' 5='(5) OTHER' ;
  VALUE afdrug2f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) COCAINE' 2='(2) HEROIN' 3='(3) ALCOHOL' 4='(4) MARIJUANA' 5='(5) OTHER' ;
  VALUE quexstat  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) NTEQ ONLY' 3='(3) NTEQ & NPAQ'
                  4='(4) NTEQ, NPAQ, & NPRAF' 5='(5) NTEQ & NPRAF' 6='(6) NPAQ ONLY'
                  7='(7) NPAQ AND NPRAF' 8='(8) NPRAF ONLY' ;
  VALUE bcstat    -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NBAR & NCAR' 2='(2) NBAR ONLY' 4='(4) NO NBAR/ NCAR' ;
  VALUE uristat   -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NO NPAQ' 2='(2) NOT ASKED' 3='(3) ASKED, URINE NA' 4='(4) GOOD DATA' ;
  VALUE loscensr  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NOT CENSORED' 1='(1) MIN LOS' 2='(2) MAX LOS' 3='(3) ESTIMATED LOS'
                  4='(4) MISSING LOS' ;
  VALUE durattx   -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' ;
  VALUE duraptx   -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' ;
  VALUE durapdp   -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' ;
  VALUE tfscomp   -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) STILL IN TX' 2='(2) TX COMPLETED' 3='(3) TX NOT COMPLETED'
                  4='(4) INCONSISTENT DATA' ;
  VALUE nriqltar  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) CONCORDANT' 2='(2) SELF RPT>STATE RPT'
                  3='(3) STATE RPT>SELF RPT' ;
  VALUE nriqdrug  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) CONCORDANT' 2='(2) SELF RPT>STATE RPT'
                  3='(3) STATE RPT>SELF RPT' ;
  VALUE npaqar    -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) CONCORDANT' 2='(2) SELF RPT>STATE RPT'
                  3='(3) STATE RPT>SELF RPT' ;
  VALUE fldisp    -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  10='(10) NO PROBLEM WITH SAMPLE' 20='(20) URINE WAS COLD'
                  40='(40) SUSPECT ADULTERATION' 50='(50) OTHER' 79='(79) CONDITION MISSING' ;
  VALUE labdisp   -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  11='(11) SAMPLE SEEMS OK' 12='(12) SAMPLE SEEMS ADULTERATED'
                  13='(13) INSUFFICIENT SAMPLE' 14='(14) SAMPLE CONDITION MISSING' ;
  VALUE can       -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NEGATIVE' 1='(1) POSITIVE' ;
  VALUE coc       -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NEGATIVE' 1='(1) POSITIVE' ;
  VALUE pcp       -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NEGATIVE' 1='(1) POSITIVE' ;
  VALUE opi       -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NEGATIVE' 1='(1) POSITIVE' ;
  VALUE amp       -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NEGATIVE' 1='(1) POSITIVE' ;
  VALUE ben       -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NEGATIVE' 1='(1) POSITIVE' ;
  VALUE met       -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NEGATIVE' 1='(1) POSITIVE' ;
  VALUE alc       -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NEGATIVE' 1='(1) POSITIVE' ;
  VALUE rbeervol  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' ;
  VALUE rwinevol  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' ;
  VALUE rliquvol  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=1311;
INPUT
        CASEID 1-7              R2 8                    R5M1 9-10
        R15 11-12               PRGMTYPE 13-14          TRTMENT 15-16
        TRT2 17-18              PRG2 19-20              CELL 21-22
        CELL2 23-24             R17 25-26               R19 27-28
        R21 29-30               R24M1 31-32             R24M2 33-34
        R24M3 35-36             R24M4 37-38             R24M6 39-40
        R24M7 41-42             R24M8 43-44             R24M9 45-46
        R24M10 47-48            R24M11 49-50            R24M12 51-52
        R24M13 53-54            R24M14 55-56            R24M15 57-58
        R24M16 59-60            R24M17 61-62            R24M18 63-64
        R24M19 65-66            R24M21 67-68            R24M22 69-70
        R25M1 71-72             R25M2 73-74             R25M3 75-76
        R25M4 77-78             R27 79-82               R29 83-84
        R34 85-86               R35 87-88               R39 89-90
        R41 91-92               R42 93-94               R44M1 95-96
        R46 97-98               R47 99-100              R50 101-102
        R53 103-104             R55 105-106             R56M1 107-108
        R56M2 109-110           R56M3 111-112           R56M4 113-114
        R56M5 115-116           R56M6 117-118           R56M8 119-120
        R56M9 121-122           R58 123-124             R61 125-126
        R62 127-128             R64 129-130             R67 131-132
        R71 133-134             R72 135-136             R74 137-138
        R76 139-140             R77 141-142             R79 143-146
        R84M1 147-148           R84M2 149-150           R84M3 151-152
        R84M4 153-154           R84M5 155-156           R84M6 157-158
        R84M7 159-160           R84M8 161-162           R84M10 163-164
        R84M12 165-166          R90M1 167-168           R90M2 169-170
        R90M3 171-172           R90M4 173-174           R90M5 175-176
        R90M6 177-178           R90M7 179-180           R90M8 181-182
        R90M9 183-184           R90M10 185-186          R90M11 187-188
        R91 189-190             R92 191-192             R93 193-194
        R97 195-196             R99 197-198             R100M1 199-200
        R100M2 201-202          R100M3 203-204          R100M4 205-206
        R100M5 207-208          R100M6 209-210          R102 211-214
        R108A1 215-216          R108A2 217-218          R108A3 219-220
        R108A4 221-222          R108A5 223-224          R108A6 225-226
        R108A7 227-228          R108A8 229-230          R108A9 231-232
        R108A10 233-234         R108A11 235-236         R108A12 237-238
        R113M1 239-240          R113M2 241-242          R113M3 243-244
        R113M4 245-246          R113M5 247-248          R113M6 249-250
        R113M7 251-252          R113M8 253-254          R113M9 255-256
        R113M10 257-258         R113M11 259-260         R113M12 261-262
        R113M13 263-264         R113M14 265-266         R114M1 267-268
        R114M2 269-270          R114M3 271-272          R114M4 273-274
        R114M5 275-276          R114M6 277-278          R114M7 279-280
        R114M8 281-282          R116A1 283-284          R117A1 285-286
        R120A1 287-288          R122A1 289-290          R116A2 291-292
        R117A2 293-294          R120A2 295-296          R122A2 297-298
        R123A2 299-300          R116A3 301-302          R117A3 303-304
        R118A3 305-306          R119A3 307-308          R120A3 309-310
        R122A3 311-312          R123A3 313-314          R116A4 315-316
        R117A4 317-318          R118A4 319-320          R119A4 321-322
        R120A4 323-324          R122A4 325-326          R123A4 327-328
        R116A5 329-330          R117A5 331-332          R120A5 333-334
        R122A5 335-336          R116A6 337-338          R117A6 339-340
        R120A6 341-342          R122A6 343-344          R116A7 345-346
        R117A7 347-348          R120A7 349-350          R122A7 351-352
        R123A7 353-354          R116A8 355-356          R117A8 357-358
        R120A8 359-360          R122A8 361-362          R116A9 363-364
        R117A9 365-366          R120A9 367-368          R122A9 369-370
        R123A9 371-372          R116A10 373-374         R117A10 375-376
        R120A10 377-378         R122A10 379-380         R123A10 381-382
        R116A11 383-384         R117A11 385-386         R120A11 387-388
        R122A11 389-390         R123A11 391-392         R116A12 393-394
        R117A12 395-396         R120A12 397-398         R122A12 399-400
        R124 401-402            R125 403-404            R126 405-406
        R127 407-408            R128 409-410            R129 411-412
        R130 413-414            R131 415-416            R132 417-418
        R133 419-420            R135 421-422            R136 423-424
        R137 425-426            R138 427-428            R139 429-430
        R140 431-432            R142A1 433-434          R143A1 435-436
        R144A1 437-438          R147A1 439-440          R142A2 441-442
        R143A2 443-444          R144A2 445-446          R147A2 447-448
        R142A3 449-450          R143A3 451-452          R144A3 453-454
        R155 455-456            R156 457-458            R157 459-460
        R159 461-462            R160 463-464            R161 465-466
        R162 467-468            R171 469-470            R172 471-472
        R173 473-474            R174 475-476            R175 477-478
        R176 479-480            R177 481-482            R178 483-484
        R179 485-486            R182A1 487-488          R184A1 489-490
        R185A1 491-492          R182A2 493-494          R184A2 495-496
        R185A2 497-498          R182A3 499-500          R184A3 501-502
        R185A3 503-504          R182A4 505-506          R185A4 507-508
        R182A5 509-510          R185A5 511-512          R182A6 513-514
        R185A6 515-516          R182A7 517-518          R185A7 519-520
        R182A8 521-522          R185A8 523-524          R182A9 525-526
        R185A9 527-528          R187 529-530            R189 531-532
        R190 533-534            R191 535-536            R192 537-538
        R193 539-540            R194 541-542            R195 543-544
        R198A1 545-546          R198A2 547-548          R198A3 549-550
        R198A4 551-552          R198A5 553-554          R200A1 555-556
        R202A1 557-558          R200A2 559-560          R202A2 561-562
        R200A3 563-564          R202A3 565-566          R200A4 567-568
        R202A4 569-570          R200A5 571-572          R202A5 573-574
        R203 575-576            R204M1 577-578          R204M2 579-580
        R204M3 581-582          R204M4 583-584          R204M5 585-586
        R204M6 587-588          R205 589-590            R206M1 591-592
        R206M2 593-594          R206M3 595-596          R206M4 597-598
        R206M5 599-600          R206M6 601-602          R207 603-604
        R208M1 605-606          R208M2 607-608          R211 609-610
        R212 611-612            R213 613-614            R214 615-616
        R216 617-618            R218 619-620            R219 621-622
        R220 623-624            R221 625-626            R222 627-628
        R223 629-630            R225 631-632            R226 633-634
        R227 635-636            R228 637-638            R229 639-640
        R231 641-642            R232 643-644            R233 645-646
        R234 647-648            R236 649-650            R237 651-652
        R238 653-654            R239 655-656            R240 657-658
        R241 659-660            R242 661-662            R244 663-664
        R245 665-666            R246 667-668            R247 669-670
        R248 671-672            R250 673-674            R251 675-676
        R253 677-681            R255 682-683            R256 684-685
        R258 686-687            R259 688-690            R260 691-692
        R262 693-694            R263 695-696            R264 697-698
        R270M1 699-700          R270M2 701-702          R270M3 703-704
        R270M4 705-706          R271 707-708            R272M1 709-710
        R272M2 711-712          R272M3 713-714          R273 715-716
        R274 717-718            R275 719-720            R276 721-722
        R277 723-724            R278 725-726            R279 727-728
        R280 729-730            R281 731-732            R282 733-734
        R287 735-736            R288 737-738            R289 739-740
        R290 741-742            R291 743-744            R292 745-746
        R293 747-748            R294 749-750            R295 751-752
        R296 753-754            R297 755-756            R298 757-758
        R299 759-760            R300 761-762            R301 763-764
        R302 765-766            R303 767-768            R304 769-770
        R305 771-772            R306 773-774            R307 775-776
        R308 777-778            R309 779-780            R310 781-782
        R311 783-784            R313A1 785-786          R313A2 787-788
        R313A3 789-790          R314 791-795            R322 796-797
        R323 798-799            R324 800-801            R325 802-803
        R326 804-805            R327 806-807            R328 808-809
        R329 810-811            R330 812-813            R331 814-815
        R332 816-817            R333 818-819            R334 820-821
        R335 822-823            R336 824-825            R337 826-827
        R338 828-829            R339 830-831            R340 832-833
        R341 834-835            R344A2 836-837          R345A2 838-839
        R344A3 840-841          R345A3 842-843          R345A5 844-845
        R345A10 846-847         R344A11 848-849         R345A11 850-851
        R344A12 852-853         R345A12 854-855         R344A15 856-857
        R345A15 858-859         R345A16 860-861         R345A17 862-863
        R344A18 864-865         R346 866-867            R348A1 868-869
        R351A1 870-871          R348A2 872-873          R351A2 874-875
        R348A3 876-877          R351A3 878-879          R348A4 880-881
        R351A4 882-883          R348A5 884-885          R351A5 886-887
        R348A6 888-889          R351A6 890-891          R348A7 892-893
        R351A7 894-895          R348A8 896-897          R351A8 898-899
        R348A9 900-901          R351A9 902-903          R348A10 904-905
        R351A10 906-907         R348A11 908-909         R351A11 910-911
        R348A12 912-913         R351A12 914-915         R348A13 916-917
        R351A13 918-919         R348A14 920-921         R351A14 922-923
        R348A15 924-925         R351A15 926-927         R348A16 928-929
        R351A16 930-931         R348A17 932-933         R351A17 934-935
        R348A18 936-937         R351A18 938-939         R348A19 940-941
        R351A19 942-943         R348A20 944-945         R351A20 946-947
        R348A21 948-949         R351A21 950-951         R352 952-953
        R353 954-955            R354 956-957            R357 958-959
        R358 960-961            R359 962-963            R360 964-965
        R361 966-967            R362 968-969            R363 970-971
        R364 972-973            R365 974-975            R366 976-977
        R369 978-979            R371 980-981            R372 982-983
        R373 984-985            R375 986-990            R377 991-992
        R378M1 993-994          R378M2 995-996          R378M3 997-998
        R378M4 999-1000         R378M5 1001-1002        R378M6 1003-1004
        R378M7 1005-1006        R378M8 1007-1008        R378M9 1009-1010
        R378M10 1011-1012       R378M11 1013-1014       R378M12 1015-1016
        R378M13 1017-1018       R378M14 1019-1020       R378M15 1021-1022
        R378M16 1023-1024       R378M17 1025-1026       R379 1027-1028
        R380 1029-1030          R381 1031-1032          R384A1 1033-1035
        R385A1 1036-1037        R388A1 1038-1039        R389A1 1040-1041
        R389A2 1042-1043        R391 1044-1045          R392 1046-1047
        R393 1048-1049          R397M1 1050-1051        R397M2 1052-1053
        R397M3 1054-1055        R397M4 1056-1057        R397M5 1058-1059
        R397M6 1060-1061        R397M7 1062-1063        R397M8 1064-1065
        R397M9 1066-1067        R397M10 1068-1069       R397M11 1070-1071
        R399 1072-1073          R400 1074-1075          R401 1076-1077
        R403 1078-1079          R407M2 1080-1081        R409 1082-1083
        R411 1084-1085          R412 1086-1087          R413 1088-1089
        R416A1 1090-1091        R416A2 1092-1093        R416A3 1094-1095
        R416A4 1096-1097        R416A5 1098-1099        R416A6 1100-1101
        R416A7 1102-1103        R419M1 1104-1105        R419M2 1106-1107
        R420 1108-1109          R423 1110-1111          R427A1 1112-1113
        R427A2 1114-1115        R427A3 1116-1117        R427A4 1118-1119
        R427A5 1120-1121        R427A6 1122-1123        R427A7 1124-1125
        R427A8 1126-1127        R427A9 1128-1129        R427A10 1130-1131
        R428 1132-1133          R429 1134-1135          R431 1136-1137
        R436A1 1138-1139        R437A1 1140-1141        R436A2 1142-1143
        R437A2 1144-1145        R436A3 1146-1147        R437A3 1148-1149
        R436A4 1150-1151        R437A4 1152-1153        R436A5 1154-1155
        R437A5 1156-1157        R439 1158-1159          R440 1160-1161
        R441 1162-1163          R442 1164-1165          R443 1166-1167
        R444 1168-1169          R445 1170-1171          R447 1172-1173
        R448 1174-1175          R449 1176-1177          R450 1178-1179
        R451 1180-1181          R452 1182-1183          R454A1 1184-1185
        R456A1 1186-1187        R455A2 1188-1189        R456A2 1190-1191
        R455A3 1192-1193        R456A3 1194-1195        R457 1196-1197
        R458 1198-1199          R459M1 1200-1201        R459M2 1202-1203
        R459M3 1204-1205        R459M4 1206-1207        R462M1 1208-1209
        R462M4 1210-1211        R462M5 1212-1213        R463 1214-1215
        R464 1216-1217          R465 1218-1219          R466 1220-1221
        R467 1222-1223          R468 1224-1225          R469 1226-1227
        R470 1228-1229          R471 1230-1231          R472 1232-1233
        R474 1234-1238          RTOTANS 1239-1241       RTOTREF 1242-1243
        RTOTDK 1244-1245        AFDRUG1 1246-1247       AFDRUG2 1248-1249
        QUEXSTAT 1250-1251      BCSTAT 1252-1253        URISTAT 1254-1255
        LOS 1256-1260 .2        LOSCENSR 1261-1262      DURATTX 1263-1267 .2
        DURAPTX 1268-1269       DURAPDP 1270-1274 .2    TFSCOMP 1275-1276
        NRIQLTAR 1277-1278      NRIQDRUG 1279-1280      NPAQAR 1281-1282
        FLDISP 1283-1284        LABDISP 1285-1286       CAN 1287-1288
        COC 1289-1290           PCP 1291-1292           OPI 1293-1294
        AMP 1295-1296           BEN 1297-1298           MET 1299-1300
        ALC 1301-1302           RBEERVOL 1303-1305      RWINEVOL 1306-1308
        RLIQUVOL 1309-1311      ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'PATIENT CASEID'
   R2      = 'TREATMENT MODALITY'
   R5M1    = 'INTAKE PERIODS'
   R15     = 'LANGUAGE FLAG'
   PRGMTYPE= 'PROGRAM TYPE'
   TRTMENT = 'TREATMENT MODALITY'
   TRT2    = 'REVISED TREATMENT MODALITY'
   PRG2    = 'REVISED PROGRAM TYPE'
   CELL    = 'ANALYSIS VARIALBLE'
   CELL2   = 'ANALYSIS VARIABLE V.2'
   R17     = 'SETTING OF INTERVIEW'
   R19     = 'EVER LOCKED UP BEFORE'
   R21     = 'HOW LONG LOCKED UP'
   R24M1   = 'IN FOR DRUG POSSESSION'
   R24M2   = 'IN FOR DRUG SALE OR MANUFACTURING'
   R24M3   = 'IN FOR DRIVING WHILE INTOXICATED'
   R24M4   = 'IN FOR PROSTITUTION OR SOLICITATION'
   R24M6   = 'IN FOR FORGERY, ETC'
   R24M7   = 'IN FOR BOOKMAKING/NUMBERS/GAMBLING'
   R24M8   = 'IN FOR RECEIVING STOLEN GOODS'
   R24M9   = 'IN FOR MOTOR VEHICLE THEFT'
   R24M10  = 'IN FOR SHOPLIFTING'
   R24M11  = 'IN FOR BREAKING AND ENTERING/BURGLARY'
   R24M12  = 'IN FOR ARMED ROBBERY/ROBBERY BY FORCE'
   R24M13  = 'IN FOR OTHER THEFT'
   R24M14  = 'IN FOR ARSON'
   R24M15  = 'IN FOR VANDALISM'
   R24M16  = 'IN FOR SERIOUS ASSAULT'
   R24M17  = 'IN FOR SIMPLE ASSAULT/FIGHTING'
   R24M18  = 'IN FOR FORCIBLE RAPE/SEXUAL ASSAULT'
   R24M19  = 'IN FOR MURDER/MANSLAUGHTER'
   R24M21  = 'IN FOR OTHER'
   R24M22  = 'IN FOR CANNOT CODE'
   R25M1   = 'AWAITING TRIAL OR TRIAL PROCEEDINGS'
   R25M2   = 'AWAITING SENTENCING'
   R25M3   = 'SERVING A SENTENCE'
   R25M4   = 'SOMETHING ELSE'
   R27     = 'SECTION JP ELAPSED TIME'
   R29     = 'GENDER'
   R34     = 'AGE FROM BIRTH DATE'
   R35     = 'AGE CHECK'
   R39     = 'BORN IN US'
   R41     = 'MOTHER BORN IN US'
   R42     = 'FATHER BORN IN US'
   R44M1   = 'RACE/ETHNICITY'
   R46     = 'OTHER LANGUAGE SPOKEN AS CHILD'
   R47     = 'LANGUAGES SPOKEN'
   R50     = 'LANGUAGE PREFERRED'
   R53     = 'ABILITY TO READ ENGLISH'
   R55     = 'NOW IN SCHOOL/TRAINING'
   R56M1   = 'ELEMENTARY SCHOOL/MIDDLE SCHOOL/JUNIOR H'
   R56M2   = 'HIGH SCHOOL'
   R56M3   = 'GED PROGRAM'
   R56M4   = 'JUNIOR (2-YEAR) COLLEGE'
   R56M5   = '4-YEAR COLLEGE/UNIVERSITY'
   R56M6   = 'TECHNICAL/TRADE/VOCATIONAL SCHOOL'
   R56M8   = 'SPECIAL EDUCATION PROGRAM'
   R56M9   = 'JOB CORPS OR OTHER SCHOOL/TRAINING'
   R58     = 'HIGHEST GRADE ATTENDED'
   R61     = 'HAVE HS DIPLOMA/GED?'
   R62     = 'HIGH SCHOOL DIPLOMA/GED'
   R64     = '(OTHER) DIPLOMAS/DEGREES'
   R67     = 'SERVED ON ACTIVE DUTY'
   R71     = 'LAST SCHOOL GRADES'
   R72     = 'EVER EXPELLED FROM SCHOOL'
   R74     = 'EXPELLED MORE THAN ONE TIME'
   R76     = 'AGE WHEN (FIRST) EXPELLED'
   R77     = 'DRUGS CAUSED TO LEAVE SCHOOL'
   R79     = 'SECTION A ELAPSED TIME'
   R84M1   = 'REFERRAL SOURCE - DRUG TREATMENT STAFF'
   R84M2   = 'REFERRAL SOURCE - CRIMINAL JUSTICE PERSO'
   R84M3   = 'REFERRAL SOURCE - HEALTH AGENCY STAFF'
   R84M4   = 'REFERRAL SOURCE - SCHOOL TEACHER'
   R84M5   = 'REFERRAL SOURCE - OTHER PUBLIC SERVICE A'
   R84M6   = 'REFERRAL SOURCE - EMPLOYEAR'
   R84M7   = 'REFERRAL SOURCE - SPOUSE, PARTNER, FAMIL'
   R84M8   = 'REFERRAL SOURCE - FRIEND, COWORKER, FELL'
   R84M10  = 'REFERRAL SOURCE - OTHER'
   R84M12  = 'REFERRAL SOURCE - SELF'
   R90M1   = 'REASON FOR TREATMENT - DRUG AVAILABILITY'
   R90M2   = 'REASON FOR TREATMENT - FINANCIAL'
   R90M3   = 'REASON FOR TREATMENT - PRESSURE FROM'
   R90M4   = 'REASON FOR TREATMENT - PRESSURE TO IMPRO'
   R90M5   = 'REASON FOR TREATMENT - PRESSURE FROM TEA'
   R90M6   = 'REASON FOR TREATMENT - JOB'
   R90M7   = 'REASON FOR TREATMENT - PARENTING ISSUES'
   R90M8   = 'REASON FOR TREATMENT - HEALTH ISSUES'
   R90M9   = 'REASON FOR TREATMENT - DESIRE FOR SERVIC'
   R90M10  = 'REASON FOR TREATMENT - GENERAL PERSONAL'
   R90M11  = 'REASON FOR TREATMENT - OTHER'
   R91     = 'TROUBLED BY USE'
   R92     = 'IMPORTANCE OF TREATMENT'
   R93     = 'HOW LONG AGO NAME PUT IN'
   R97     = 'KEPT FROM TREATMENT'
   R99     = 'PROBLEMS GETTING TREATMENT'
   R100M1  = 'TRANSPORTATION PROBLEMS'
   R100M2  = 'WORK SCHEDULE CONFLICT'
   R100M3  = 'SCHOOL/TRAINING SCHEDULE CONFLICT'
   R100M4  = 'CHILD CARE PROBLEMS'
   R100M5  = 'COST OF TREATMENT'
   R100M6  = 'OTHER PROBLEMS GETTING TREATMENT'
   R102    = 'SECTION B ELAPSED TIME'
   R108A1  = 'EVER TRIED INHALANTS'
   R108A2  = 'EVER TRIED MARIJUANA/HASHISH'
   R108A3  = 'EVER TRIED CRACK'
   R108A4  = 'EVER TRIED COCAINE'
   R108A5  = 'EVER TRIED PCP'
   R108A6  = 'EVER TRIED HALLUCINOGENS OR PSYCHEDELICS'
   R108A7  = 'EVER TRIED HEROIN'
   R108A8  = 'EVER TRIED ILLEGAL METHADONE'
   R108A9  = 'EVER TRIED OTHER NARCOTICS'
   R108A10 = 'EVER TRIED ILLEGAL UPPERS'
   R108A11 = 'EVER TRIED OTHER DOWNERS'
   R108A12 = 'EVER TRIED OTHER DRUGS'
   R113M1  = 'IN TX FOR INHALANTS'
   R113M2  = 'IN TX FOR MARIJUANA/HASHISH'
   R113M3  = 'IN TX FOR CRACK'
   R113M4  = 'IN TX FOR COCAINE'
   R113M5  = 'IN TX FOR PCP'
   R113M6  = 'IN TX FOR HALLUCINOGENS OR PSYCHEDELICS'
   R113M7  = 'IN TX FOR UPPERS'
   R113M8  = 'IN TX FOR DOWNERS'
   R113M9  = 'IN TX FOR HEROIN'
   R113M10 = 'IN TX FOR ILLEGAL METHADONE'
   R113M11 = 'IN TX FOR OTHER NARCOTICS'
   R113M12 = 'IN TX FOR ALCOHOL'
   R113M13 = 'IN TX FOR OTHER'
   R113M14 = 'IN TX FOR NONE'
   R114M1  = 'USED WITH NO ONE'
   R114M2  = 'USED WITH FRIENDS'
   R114M3  = 'USED WITH BOYFRIEND OR GIRLFRIEND'
   R114M4  = 'USED WITH SPOUSE OR PARTNER'
   R114M5  = 'USED WITH BROTHERS AND/OR SISTERS'
   R114M6  = 'USED WITH PARENTS'
   R114M7  = 'USED WITH OTHER FAMILY MEMBERS'
   R114M8  = 'USED WITH SOMEONE ELSE'
   R116A1  = 'AGE FIRST USED INHALANTS'
   R117A1  = '2WK USE OF INHALANTS?'
   R120A1  = 'LAST USE OF INHALANTS'
   R122A1  = 'DAYS USED INHALANTS MOST'
   R116A2  = 'AGE FIRST USED MARIJUANA'
   R117A2  = '2WK USE OF MARIJUANA?'
   R120A2  = 'LAST USE OF MARIJUANA'
   R122A2  = 'DAYS USED MARIJUANA MOST'
   R123A2  = 'DAYS USED MARIJUANA LAST 30'
   R116A3  = 'AGE FIRST USED CRACK'
   R117A3  = '2WK USE OF CRACK?'
   R118A3  = '48HR USE OF CRACK?'
   R119A3  = 'LAST 48HR USE OF CRACK'
   R120A3  = 'LAST USE OF CRACK'
   R122A3  = 'DAYS USED CRACK MOST'
   R123A3  = 'DAYS USED CRACK LAST 30'
   R116A4  = 'AGE FIRST USED COCAINE POWDER'
   R117A4  = '2WK USE OF COCAINE POWDER?'
   R118A4  = '48HR USE OF COCAINE POWDER?'
   R119A4  = 'LAST 48HR USE OF COCAINE POWDER?'
   R120A4  = 'LAST USE OF COCAINE POWDER'
   R122A4  = 'DAYS USED COCAINE POWDER MOST'
   R123A4  = 'DAYS USED COCAINE POWDER LAST 30'
   R116A5  = 'AGE FIRST USED PCP'
   R117A5  = '2WK USE OF PCP?'
   R120A5  = 'LAST USE OF PCP'
   R122A5  = 'DAYS USED PCP MOST'
   R116A6  = 'AGE FIRST USED HALLUCINOGENS'
   R117A6  = '2WK USE OF HALLUCINOGENS?'
   R120A6  = 'LAST USE OF HALLUCINOGENS'
   R122A6  = 'DAYS USED HALLUCINOGENS MOST'
   R116A7  = 'AGE FIRST USED HEROIN'
   R117A7  = '2WK USE OF HEROIN?'
   R120A7  = 'LAST USE OF HEROIN'
   R122A7  = 'DAYS USED HEROIN MOST'
   R123A7  = 'DAYS USED HEROIN LAST 30'
   R116A8  = 'AGE FIRST USED ILLEGAL METHADONE'
   R117A8  = '2WK USE OF ILLEGAL METHADONE?'
   R120A8  = 'LAST USE OF ILLEGAL METHADONE'
   R122A8  = 'DAYS USED ILLEGAL METHADONE MOST'
   R116A9  = 'AGE FIRST USED OTHER NARCOTICS'
   R117A9  = '2WK USE OF OTHER NARCOTICS?'
   R120A9  = 'LAST USE OF OTHER NARCOTICS'
   R122A9  = 'DAYS USED OTHER NARCOTICS MOST'
   R123A9  = 'DAYS USED OTHER NARCOTICS LAST 30'
   R116A10 = 'AGE FIRST USED UPPERS'
   R117A10 = '2WK USE OF UPPERS?'
   R120A10 = 'LAST USE OF UPPERS'
   R122A10 = 'DAYS USED UPPERS MOST'
   R123A10 = 'DAYS USED UPPERS LAST 30'
   R116A11 = 'AGE FIRST USED DOWNERS'
   R117A11 = '2WK USE OF DOWNERS?'
   R120A11 = 'LAST USE OF DOWNERS'
   R122A11 = 'DAYS USED DOWNERS MOST'
   R123A11 = 'DAYS USED DOWNERS LAST 30'
   R116A12 = 'AGE FIRST USED OTHER DRUG USED'
   R117A12 = '2WK USE OF OTHER DRUG USED?'
   R120A12 = 'LAST USE OF OTHER DRUG USED'
   R122A12 = 'DAYS USED OTHER DRUG USED MOST'
   R124    = 'HOSPITALIZED FOR OVERDOSE?'
   R125    = 'LAST OVERDOSED ON DRUGS'
   R126    = 'TIMES OVERDOSED IN LAST 12 MONTHS'
   R127    = 'CASH SPENT ON DRUGS LAST 30 DAYS'
   R128    = 'INJECTED DRUGS?'
   R129    = 'HAD DRUGS INJECTED?'
   R130    = 'LAST INJECTED DRUGS'
   R131    = 'DAYS INJECTED DRUGS IN LAST 30'
   R132    = 'SHARED NEEDLE OR WORKS?'
   R133    = 'LAST SHARED NEEDLE OR WORKS'
   R135    = 'HOW OFTEN SHARED NEEDLE LAST 30DYS/12MOS'
   R136    = 'HOW OFTEN CLEANED NDLE LAST 30DYS/12MOS'
   R137    = 'HOW OFTEN SHARED WORKS LAST 30DYS/12MOS'
   R138    = 'DAYS SHARED STRANGER''S NDLE/WRKS IN LAS'
   R139    = 'DRANK ALCOHOL?'
   R140    = 'DAYS DRANK ALCOHOL IN LAST 30'
   R142A1  = 'DAYS DRANK BEER IN LAST 30'
   R143A1  = 'AMOUNT OF BEER DRUNK PER DAY'
   R144A1  = 'UNIT OF BEER DRUNK'
   R147A1  = 'VOLUME OF BEER UNIT'
   R142A2  = 'DAYS DRANK WINE IN LAST 30'
   R143A2  = 'AMOUNT OF WINE DRUNK PER DAY'
   R144A2  = 'UNIT OF WINE DRUNK'
   R147A2  = 'VOLUME OF WINE UNIT'
   R142A3  = 'DAYS DRANK LIQUOR IN LAST 30'
   R143A3  = 'AMOUNT OF LIQUOR DRUNK PER DAY'
   R144A3  = 'UNIT OF LIQUOR DRUNK'
   R155    = 'DAYS GOTTEN DRUNK IN LAST 30'
   R156    = 'TIMES DRUNK BEFORE AGE 15'
   R157    = 'ALCOHOL DT''S?'
   R159    = 'HOSPITALIZED FOR DRINKING?'
   R160    = 'RECEIVED HELP ABOUT DRINKING?'
   R161    = 'TROUBLED/BOTHERED BY OWN ALCOHOL USE'
   R162    = 'IMPORTANCE OF ALCOHOL ABUSE TX'
   R171    = 'STAYED IN OWN APT 12 MONTHS?'
   R172    = 'STAYED IN OTHER''S APT 12 MONTHS?'
   R173    = 'STAYED IN HOTEL ROOM 12 MONTHS?'
   R174    = 'STAYED IN HOMELESS SHELTER 12 MONTHS?'
   R175    = 'STAYED IN OTHER SHELTER 12 MONTHS?'
   R176    = 'STAYED IN HOSPITAL 12 MONTHS?'
   R177    = 'STAYED IN JAIL 12 MONTHS?'
   R178    = 'STAYED IN GROUP HOME 12 MONTHS?'
   R179    = 'STAYED IN OTHER PLACE 12 MONTHS?'
   R182A1  = 'STAYED IN OWN HOME 30 DAYS'
   R184A1  = 'GOV''T PAID  OWN HOME'
   R185A1  = 'LONGEST STAY OWN HOME'
   R182A2  = 'STAYED IN OTHER''S HOME 30 DAYS'
   R184A2  = 'GOV''T PAID  OTHER''S HOME'
   R185A2  = 'LONGEST STAY OTHER''S HOME 12  MOS'
   R182A3  = 'STAYED IN HOTEL ROOM 30 DAYS'
   R184A3  = 'GOV''T PAID  HOTEL ROOM'
   R185A3  = 'LONGEST STAY HOTEL ROOM 12  MOS'
   R182A4  = 'STAYED IN HOMELESS SHELTER 30 DAYS'
   R185A4  = 'LONGEST STAY HOMELESS SHELTER 12  MOS'
   R182A5  = 'STAYED IN OTHER SHELTER 30 DAYS'
   R185A5  = 'LONGEST STAY OTHER SHELTER 12  MOS'
   R182A6  = 'STAYED IN HOSPITAL 30 DAYS'
   R185A6  = 'LONGEST STAY HOSPITAL 12  MOS'
   R182A7  = 'STAYED IN JAIL 30 DAYS'
   R185A7  = 'LONGEST STAY JAIL 12  MOS'
   R182A8  = 'STAYED IN GROUP HOME 30 DAYS'
   R185A8  = 'LONGEST STAY GROUP HOME 12  MOS'
   R182A9  = 'STAYED IN OTHER PLACE 30 DAYS'
   R185A9  = 'LONGEST STAY OTHER PLACE 12  MOS'
   R187    = 'PLACE STAYED LAST NIGHT'
   R189    = 'STAYED IN PUBLIC HOUSING LAST NIGHT?'
   R190    = 'IMPORTANCE OF HOUSING HELP'
   R191    = 'SAW DRUG USE/SALE NEAR HOME LAST 7 DAYS?'
   R192    = 'APPROACHED TO USE/BUY DRUGS LAST 7 DAYS?'
   R193    = 'SHOOTING/KNIFING NEARBY PAST 7DYS?'
   R194    = 'MUGGING/BEATING NEARBY PAST 7DYS?'
   R195    = 'KNOWN PEOPLE KILLED LAST 12MO'
   R198A1  = 'LIVED WITH SPOUSE/PARTNER?'
   R198A2  = 'LIVED WITH MOTHER?'
   R198A3  = 'LIVED WITH FATHER?'
   R198A4  = 'LIVED WITH MINOR CHILDREN?'
   R198A5  = 'LIVED WITH ADULT CHILDREN?'
   R200A1  = 'TIME LIVED WITH SPOUSE/PARTNER'
   R202A1  = 'NOW LIVE WITH SPOUSE/PARTNER?'
   R200A2  = 'TIME LIVED WITH MOTHER'
   R202A2  = 'NOW LIVE WITH MOTHER?'
   R200A3  = 'TIME LIVED WITH FATHER'
   R202A3  = 'NOW LIVE WITH FATHER?'
   R200A4  = 'TIME LIVED WITH MINOR CHILDREN'
   R202A4  = 'NOW LIVE WITH MINOR CHILDREN?'
   R200A5  = 'TIME LIVED WITH ADULT CHILDREN'
   R202A5  = 'NOW LIVE WITH ADULT CHILDREN?'
   R203    = 'CURRENTLY LIVING WITH  ALCOHOLIC?'
   R204M1  = 'SPOUSE/PARTNER ALCOHOLIC'
   R204M2  = 'MOTHER ALCOHOLIC'
   R204M3  = 'FATHER ALCOHOLIC'
   R204M4  = 'MINOR CHILD ALCOHOLIC'
   R204M5  = 'ADULT CHILD ALCOHOLIC'
   R204M6  = 'OTHER PERSON ALCOHOLIC'
   R205    = 'CURRENTLY LIVING WITH DRUG USER?'
   R206M1  = 'SPOUSE/PARTNER DRUG USER'
   R206M2  = 'MOTHER DRUG USER'
   R206M3  = 'FATHER DRUG USER'
   R206M4  = 'MINOR CHILD DRUG USER'
   R206M5  = 'ADULT CHILD DRUG USER'
   R206M6  = 'OTHER PERSON DRUG USER'
   R207    = 'CURRENTLY LIVING WITH 12-STEP GOER?'
   R208M1  = 'SPOUSE/PARTNER 12-STEP GOER'
   R208M2  = 'ALL OTHER 12-STEP GOER'
   R211    = 'NON-COHABITANT PARTNER?'
   R212    = 'PARTNER ABUSING ALCOHOL?'
   R213    = 'PARTNER USING DRUGS?'
   R214    = 'PARTNER IN 12-STEP/TREATMENT?'
   R216    = 'NUMBER OF CHILDREN CURRENTLY RAISING'
   R218    = 'EVER RAISED CHILDREN?'
   R219    = 'IN TREATMENT TO REGAIN CUSTODY?'
   R220    = 'AFRAID OF LOSING CUSTODY?'
   R221    = 'DIFFICULTY OF GETTING CHILD CARE'
   R222    = 'CURRENTLY MARRIED?'
   R223    = 'EVER MARRIED?'
   R225    = 'LIVE WITH SPOUSE?'
   R226    = 'LENGTH OF MARITAL SEPARATION'
   R227    = 'NUMBER OF DEPENDENTS'
   R228    = 'PERSON TO CONFIDE IN?'
   R229    = 'EMERGENCY SUPPORT PERSON?'
   R231    = 'AGE MET SUPPORT PERSON 1'
   R232    = 'AGE MET SUPPORT PERSON 2'
   R233    = 'AGE MET SUPPORT PERSON 3'
   R234    = 'EVER OUTPLACED BY COURTS/AGENCY?'
   R236    = 'TIMES OUTPLACED BY COURTS/AGENCY'
   R237    = 'EVER RUN AWAY FROM HOME?'
   R238    = 'TIMES RUN AWAY'
   R239    = 'EVER KICKED OUT BY PARENT/GUARDIAN?'
   R240    = 'EVER ATTACKED?'
   R241    = 'EVER BEATEN?'
   R242    = 'TIMES ATTACKED/BEATEN'
   R244    = 'EVER ATTACKED/BEATEN BEFORE AGE 18?'
   R245    = 'WHEN LAST ATTACKED'
   R246    = 'EVER BEATEN BY PARENT/GUARDIAN?'
   R247    = 'EVER BEATEN BY SPOUSE/PARTNER?'
   R248    = 'IMPORTANCE OF CHILDCARE COUNSELING'
   R250    = 'IMPORTANCE OF FAMILY COUNSELING'
   R251    = 'IMPORTANCE OF SOCIAL PROBLEMS COUNSELING'
   R253    = 'SECTION D ELAPSED TIME'
   R255    = 'PRIOR ALCOHOL TREATMENT?'
   R256    = 'PRIOR DRUG TREATMENT?'
   R258    = 'NUMBER OF PRIOR TREATMENTS'
   R259    = 'AGE AT FIRST TREATMENT'
   R260    = 'LONGEST TIME IN TREATMENT'
   R262    = 'MODALITY OF LONGEST TREATMENT'
   R263    = 'TREATMENT LAST 12 MONTHS?'
   R264    = 'ANY TREATMENT PROVIDERS LAST 12 MONTHS?'
   R270M1  = 'NUMBER OF TREATMENTS - INPATIENT'
   R270M2  = 'NUMBER OF TREATMENTS - RESIDENTIAL'
   R270M3  = 'NUMBER OF TREATMENTS - OUTPATIENT'
   R270M4  = 'NUMBER OF TREATMENTS - METHADONE'
   R271    = 'ATTENDED 12 STEP?'
   R272M1  = 'EVER ATTENDED ALCOHOL ANONYMOUS'
   R272M2  = 'EVER ATTENDED NARCOTICS ANONYMOUS'
   R272M3  = 'EVER ATTENDED COCAINE ANONYMOUS'
   R273    = 'AGE AT FIRST 12 STEP MEETING'
   R274    = 'ATTENDED > 5 MEETINGS LAST 12 MONTHS?'
   R275    = '24 HOUR MENTAL HEALTH VISIT?'
   R276    = 'AGE AT 1ST 24 HR MENTAL HEALTH VISIT'
   R277    = '# OF 24 HR MENTAL HEALTH VISITS'
   R278    = '24 HR MENTAL HEALTH VISIT LAST 12 MOS?'
   R279    = 'OUTPATIENT MENTAL HEALTH TREATMENT?'
   R280    = 'OUTPATIENT MENTAL HEALTH TMT BEFORE AGE 18?'
   R281    = '# OF MHEALTH VISITS LAST 12 MOS'
   R282    = 'PSYCHOTROPIC DRUGS TAKEN LAST 7 DAYS?'
   R287    = 'SUDDEN FEAR W/OUT DANGER?'
   R288    = 'SUDDEN IRRATIONAL FEAR?'
   R289    = 'DRUG-INDUCED SUDDEN FEAR'
   R290    = 'TREMBLING WHEN FRIGHTENED?'
   R291    = 'SWEATING WHEN FRIGHTENED?'
   R292    = 'TROUBLE BREATHING WHEN FRIGHTENED?'
   R293    = 'HEART POUNDING WHEN FRIGHTENED?'
   R294    = 'DRUG-FREE SUDDEN FEAR LAST 12 MONTHS?'
   R295    = 'SEVERELY DEPRESSED FOR TWO WEEKS?'
   R296    = 'LOST INTEREST IN LIFE FOR 2 WEEKS?'
   R297    = 'DRUG-INDUCED 2 WEEK PERIODS'
   R298    = 'DRUG-INDUCED 2 WK PERIODS LAST 12 MOS?'
   R299    = 'ATTEMPTED SUICIDE?'
   R300    = 'SUICIDE ATTEMPTED > ONCE?'
   R301    = 'DRUG-INDUCED SUICIDE ATTEMPT?'
   R302    = 'DRUG-INDUCED SUICIDE ATTEMPTS'
   R303    = 'SUICIDE ATTEMPT LAST 12 MONTHS?'
   R304    = 'DRUG-INDUCED ATTEMPTS LAST 12 MONTHS'
   R305    = 'SUICIDAL THOUGHTS?'
   R306    = 'DRUG-INDUCED SUICIDAL THOUGHTS'
   R307    = 'SUICIDAL THOUGHTS LAST 12 MONTHS?'
   R308    = 'HAD HALLUCINATIONS?'
   R309    = 'DRUG-INDUCED HALLUCINATIONS'
   R310    = 'TROUBLED/BOTHERED BY MENTAL HEALTH'
   R311    = 'IMPORTANCE OF MENTAL HEALTH TREATMENT'
   R313A1  = 'ABILITY TO NOT INTERRUPT PRE AGE 12'
   R313A2  = 'ABILITY TO STAY IN SEAT PRE AGE 12'
   R313A3  = 'ABILITY TO FINISH THINGS PRE AGE 12'
   R314    = 'SECTION E ELAPSED TIME'
   R322    = 'DRIVEN DRUNK/HIGH'
   R323    = 'EVER STOLE A VEHICLE'
   R324    = 'EVER SOLD DRUGS'
   R325    = 'EVER GOT CUSTOMERS FOR PROSTITUTES'
   R326    = 'EVER HAD SEX FOR MONEY/DRUGS'
   R327    = 'EVER PASSED BAD CHECKS/CREDIT CARD'
   R328    = 'EVER WORKED IN BOOKMAKING'
   R329    = 'EVER EMBEZZLED'
   R330    = 'EVER BOUGHT STOLEN GOODS'
   R331    = 'EVER SHOPLIFTED'
   R332    = 'EVER BROKE INTO HOUSE,ETC'
   R333    = 'EVER USED WEAPON/FORCE TO STEAL'
   R334    = 'EVER SET FIRE TO BUILDING/VEHICLE'
   R335    = 'EVER DESTROYED PROPERTY'
   R336    = 'EVER ATTACKED/THREATENED SOMEONE'
   R337    = 'EVER BEATEN SOMEONE UP'
   R338    = 'EVER SEVERELY HURT SOMEONE'
   R339    = 'EVER FORCED SEX ON SOMEONE'
   R340    = 'EVER KILLED SOMEONE'
   R341    = 'EVER COMMITTED OTHER OFFENSE'
   R344A2  = 'AGE STOLE A VEHICLE'
   R345A2  = 'TIMES STOLE A VEHICLE'
   R344A3  = 'AGE SOLD DRUGS'
   R345A3  = 'TIMES SOLD DRUGS'
   R345A5  = 'TIMES HAD SEX FOR MONEY/DRUGS'
   R345A10 = 'TIMES SHOPLIFTED'
   R344A11 = 'AGE BROKE INTO HOUSE,ETC'
   R345A11 = 'TIMES BROKE INTO HOUSE,ETC'
   R344A12 = 'AGE USED WEAPON/FORCE TO STEAL'
   R345A12 = 'TIMES USED WEAPON/FORCE TO STEAL'
   R344A15 = 'AGE ATTACKED/THREATENED SOMEONE'
   R345A15 = 'TIMES ATTACKED/THREATENED SOMEONE'
   R345A16 = 'TIMES BEAT SOMEONE UP'
   R345A17 = 'TIMES SEVERELY HURT SOMEONE'
   R344A18 = 'AGE FORCED SEX ON SOMEONE'
   R346    = 'BELONGED TO A GANG IN 12 MOS?'
   R348A1  = 'ARRESTED FOR DRUG POSESSION'
   R351A1  = 'ARRESTED FOR DRUG POSESSION IN 12MO'
   R348A2  = 'ARRESTED FOR SELLING DRUGS'
   R351A2  = 'ARRESTED FOR SELLING DRUGS IN 12MO'
   R348A3  = 'ARRESTED FOR DRIVING DRUNK/HIGH'
   R351A3  = 'ARRESTED FOR DRIVING DRUNK/HIGH IN 12MO'
   R348A4  = 'ARRESTED FOR PROSTITUTION'
   R351A4  = 'ARRESTED FOR PROSTITUTION IN 12MO'
   R348A5  = 'ARRESTED FOR PIMPING'
   R351A5  = 'ARRESTED FOR PIMPING IN 12MO'
   R348A6  = 'ARRESTED FOR FORGERY'
   R351A6  = 'ARRESTED FOR FORGERY IN 12MO'
   R348A7  = 'ARRESTED FOR BOOKMAKING'
   R351A7  = 'ARRESTED FOR BOOKMAKING IN 12MO'
   R348A8  = 'ARRESTED FOR STOLEN GOODS'
   R351A8  = 'ARRESTED FOR STOLEN GOODS IN 12MO'
   R348A9  = 'ARRESTED FOR STOLEN VEHICLE'
   R351A9  = 'ARRESTED FOR STOLEN VEHICLE IN 12MO'
   R348A10 = 'ARRESTED FOR SHOPLIFTING'
   R351A10 = 'ARRESTED FOR SHOPLIFTED IN 12MO'
   R348A11 = 'ARRESTED FOR BREAKING AND ENTERING'
   R351A11 = 'ARRESTED FOR BREAKING/ENTERING IN 12MO'
   R348A12 = 'ARRESTED FOR WEAPON/FORCE TO STEAL'
   R351A12 = 'ARRESTED FOR FORCE TO STEAL IN 12MO'
   R348A13 = 'ARRESTED FOR OTHER THEFT'
   R351A13 = 'ARRESTED FOR OTHER THEFT IN 12MO'
   R348A14 = 'ARRESTED FOR SETTING FIRE'
   R351A14 = 'ARRESTED FOR SETTING FIRE IN 12MO'
   R348A15 = 'ARRESTED FOR VANDALISM'
   R351A15 = 'ARRESTED FOR VANDALISM IN 12MO'
   R348A16 = 'ARRESTED FOR BEATING SOMEONE UP'
   R351A16 = 'ARRESTED FOR BEATING SOMEONE IN 12MO'
   R348A17 = 'ARRESTED FOR HURTING SOMEONE'
   R351A17 = 'ARRESTED FOR HURTING SOMEONE IN 12MO'
   R348A18 = 'ARRESTED FOR RAPE'
   R351A18 = 'ARRESTED FOR RAPE IN 12MO'
   R348A19 = 'ARRESTED FOR KILLING SOMEONE'
   R351A19 = 'ARRESTED FOR KILLING IN 12MO'
   R348A20 = 'ARRESTED FOR TRUANCY/PAROLE'
   R351A20 = 'ARRESTED FOR TRUANCY/PAROLE IN 12MO'
   R348A21 = 'ARRESTED FOR OTHER OFFENSE'
   R351A21 = 'ARRESTED FOR OTHER OFFENSE IN 12 MO'
   R352    = 'AGE WHEN FIRST ARRESTED'
   R353    = 'TIMES ARRESTED'
   R354    = 'TIMES CONVICTED'
   R357    = 'EVER IN JUVENILE FACILITY'
   R358    = 'EVER KEPT IN JAIL 24+ HOURS'
   R359    = 'LENGTH OF PRISON/JAIL STAY'
   R360    = 'RELEASED FROM JAIL/PRISON'
   R361    = 'UNDER JUVENILE PROBATION'
   R362    = 'UNDER JUVENILE PAROLE'
   R363    = 'UNDER ADULT PROBATION'
   R364    = 'UNDER ADULT PAROLE'
   R365    = 'UNDER WORK RELEASE'
   R366    = 'UNDER OTHER SUPERVISION'
   R369    = 'HOW OFTEN TALK TO OFFICER'
   R371    = 'CRIMINAL CHARGES'
   R372    = 'OUTSTANDING WARRANTS'
   R373    = 'DRUG TREATMENT REQUIRED'
   R375    = 'ELAPSED TIME SECTION F'
   R377    = 'EVER SUPPORTED BY ILLEGAL ACTIVITY?'
   R378M1  = 'SUPPORTED BY DRUG DEALING'
   R378M2  = 'SUPPORTED BY MOONSHINING'
   R378M3  = 'SUPPORTED BY PROSTITUTION'
   R378M4  = 'SUPPORTED BY PIMPING'
   R378M5  = 'SUPPORTED BY FORGERY/CREDIT FRAUD'
   R378M6  = 'SUPPORTED BY BOOKMAKING'
   R378M7  = 'SUPPORTED BY STOLEN GOODS'
   R378M8  = 'SUPPORTED BY MOTOR VEHICLE THEFT'
   R378M9  = 'SUPPORTED BY SHOPLIFTING'
   R378M10 = 'SUPPORTED BY BREAKING AND ENTERING'
   R378M11 = 'SUPPORTED BY ARMED ROBBERY'
   R378M12 = 'SUPPORTED BY OTHER THEFT'
   R378M13 = 'SUPPORTED BY ARSON'
   R378M14 = 'SUPPORTED BY AGGRAVATED ASSAULT'
   R378M15 = 'SUPPORTED BY MURDER'
   R378M16 = 'SUPPORTED BY OTHER ILLEGAL ACTIVITY'
   R378M17 = 'INTERVIEWER UNABLE TO CODE'
   R379    = 'AGE AT FIRST ILLEGAL SUPPORT'
   R380    = 'SUPPORTED ILLEGALY LAST 12 MONTHS?'
   R381    = 'CURRENTLY EMPLOYED?'
   R384A1  = 'JOB1: TYPE OF JOB'
   R385A1  = 'ANOTHER JOB?'
   R388A1  = 'HOURS WORKED AT JOB1'
   R389A1  = 'HOW LONG AT JOB1'
   R389A2  = 'HOW LONG AT JOB2'
   R391    = 'EMPLOYER REQUIRED TREATMENT?'
   R392    = 'SAW DRUG USE/SALE NEAR JOB LAST 7 DAYS?'
   R393    = 'OFFERED DRUGS NEAR WORK LAST 7 DAYS?'
   R397M1  = 'REASON FOR NOT WORKING F/T - JOB RELATED'
   R397M2  = 'REASON FOR NOT WORKING F/T - FINANCIAL'
   R397M3  = 'REASON FOR NOT WORKING F/T - CHILD CARE'
   R397M4  = 'REASON FOR NOT WORKING F/T - TRANSPORTAT'
   R397M5  = 'REASON FOR NOT WORKING F/T - FAMILY/FRIE'
   R397M6  = 'REASON FOR NOT WORKING F/T - RACE/ETHNIC'
   R397M7  = 'REASON FOR NOT WORKING F/T - LEGAL BARRI'
   R397M8  = 'REASON FOR NOT WORKING F/T - SKILL/EXPER'
   R397M9  = 'REASON FOR NOT WORKING F/T - DRUG USE'
   R397M10 = 'REASON FOR NOT WORKING F/T - ILLNESS/INJ'
   R397M11 = 'REASON FOR NOT WORKING F/T - OTHER'
   R399    = 'TIME SINCE LAST F/T JOB'
   R400    = 'LONGEST TIME HELD F/T JOB'
   R401    = 'CURRENTLY AT LONGEST HELD JOB?'
   R403    = 'TYPE OF JOB-V'
   R407M2  = 'WAGE RATE - HOURLY'
   R409    = 'MONTHS WORKED IN LAST 12'
   R411    = 'IMPORTANCE OF EMPLOYMENT COUNSELING'
   R412    = 'LIVED WITH SUPPORTER LAST 12 MONTHS?'
   R413    = 'HOW MUCH SUPPORTED BY PERSON LIVED WITH'
   R416A1  = 'INCOME FROM OWN WAGES?'
   R416A2  = 'INCOME FROM ALIMONY/CHILD SUPPORT?'
   R416A3  = 'INCOME FROM SPOUSE/PARTNER?'
   R416A4  = 'INCOME WELFARE OR RELIEF?'
   R416A5  = 'INCOME FROM UNEMPLOYMENT/DISABILITY?'
   R416A6  = 'INCOME SS/PENSION/ANNUITY?'
   R416A7  = 'INCOME FROM OTHER SOURCES?'
   R419M1  = 'INCOME - FROM OWN WAGES AND SALARIES'
   R419M2  = 'INCOME - FROM OTHER SOURCES'
   R420    = 'IMPORTANCE OF FINANCIAL COUNSELING'
   R423    = 'GENERAL HEALTH'
   R427A1  = 'PROBLEMS WITH SIGHT'
   R427A2  = 'PROBLEMS WITH HEARING'
   R427A3  = 'PROBLEMS WITH TB'
   R427A4  = 'PROBLEMS WITH BREATHING'
   R427A5  = 'PROBLEMS WITH HEART OR BLOOD'
   R427A6  = 'PROBLEMS WITH HEPATITIS'
   R427A7  = 'PROBLEMS WITH INTERNAL CONDITION'
   R427A8  = 'PROBLEMS WITH BONE OR MUSCLE'
   R427A9  = 'PROBLEMS WITH NERVE CONDITION'
   R427A10 = 'PROBLEMS WITH STD OTHER THAN AIDS'
   R428    = 'R DIAGNOSED WITH  AIDS'
   R429    = 'OTHER HEALTH PROBLEM'
   R431    = 'HEALTH LIMITS ON WORK'
   R436A1  = '# OF HETEROSEXUAL VAGINAL SEX PARTNERS'
   R437A1  = 'CONDOM USE: HETEROSEXUAL VAGINAL SEX'
   R436A2  = '# OF HETEROSEXUAL ORAL SEX PARTNERS'
   R437A2  = 'CONDOM USE: HETEROSEXUAL ORAL SEX'
   R436A3  = '# OF HETEROSEXUAL ANAL SEX PARTNERS'
   R437A3  = 'CONDOM USE: HETEROSEXUAL ANAL SEX'
   R436A4  = '# OF HOMOSEXUAL ORAL SEX PARTNERS'
   R437A4  = 'CONDOM USE: HOMOSEXUAL ORAL SEX'
   R436A5  = '# OF HOMOSEXUAL ANAL SEX PARTNERS'
   R437A5  = 'CONDOM USE: HOMOSEXUAL ANAL SEX'
   R439    = 'GOT THINGS FOR SEX'
   R440    = 'GAVE THINGS FOR SEX'
   R441    = 'HAD SEX WITH IV DRUG USER'
   R442    = 'KNEW SEX PARTNER HAD AIDS'
   R443    = 'LEARNED SEX PARTNER HAS AIDS'
   R444    = 'EVER FORCED TO HAVE SEX'
   R445    = 'TIMES FORCED TO HAVE SEX'
   R447    = 'SEX FORCED BEFORE AGE 18'
   R448    = 'TIMES BEFORE 18 FORCED TO HAVE SEX'
   R449    = 'PARENT FORCED SEX'
   R450    = 'ANY VISITS TO HOSPITAL LAST YEAR'
   R451    = 'ANY VISITS TO EMERGENCY RM LAST YEAR'
   R452    = 'ANY VISITS TO CLINIC LAST YEAR'
   R454A1  = '#-NIGHTS IN HOSPITAL'
   R456A1  = 'WAS DRUG/ALCOHOL REASON FOR HOSPITAL STA'
   R455A2  = '#-VISITS TO EMERGENCY RM'
   R456A2  = 'WAS DRUG/ALCOHOL REASON FOR EMERGENCY RM'
   R455A3  = '#-VISITS TO DOCTOR''S OFFICE/CLINIC'
   R456A3  = 'WAS DRUG/ALCOHOL REASON FOR OFFICE VISIT'
   R457    = 'IMPORTANCE OF MEDICAL TREATMENT'
   R458    = 'R HAS HEALTH PLAN/INSURANCE'
   R459M1  = 'PRIVATE HEALTH INSURANCE'
   R459M2  = 'MEDICAID'
   R459M3  = 'CHAMPUS/CHAMPVA'
   R459M4  = 'OTHER HEALTH INSURANCE'
   R462M1  = 'PAY SOURCE: PRIVATE INS./SELF/FAMILY'
   R462M4  = 'PAY SOURCE: GOVERNMENT'
   R462M5  = 'PAYMENT FROM ANOTHER SOURCE'
   R463    = 'EVER BEEN PREGNANT?'
   R464    = 'TIMES PREGNANT'
   R465    = 'TIMES GAVE BIRTH'
   R466    = 'DATE OF LAST LIVE BIRTH'
   R467    = 'DRUG USE DURING PRIOR PREGNANCY'
   R468    = 'BABIES TESTED FOR AIDS'
   R469    = 'RESULTS OF BABIES'' AIDS TESTS'
   R470    = 'R CURRENTLY PREGNANT'
   R471    = 'DRUG USE DURING CURRENT PREGNANCY'
   R472    = 'PRENATAL CARE RECEIVED'
   R474    = 'ELAPSED TIME SECTION H'
   RTOTANS = 'TOTAL QUESTIONS ANSWERED'
   RTOTREF = 'TOTAL REFUSED RESPONSES'
   RTOTDK  = 'TOTAL DON''T KNOW RESPONSE'
   AFDRUG1 = 'ADMISSION FORM PRIMARY DRUG'
   AFDRUG2 = 'ADMISSION FORM SECONDARY DRUG'
   QUEXSTAT= 'INSTRUMENT STATUS'
   BCSTAT  = 'SDU STATUS (NBAR VS NCAR)'
   URISTAT = 'STATUS OF URINE DATA'
   LOS     = 'DURATION OF INDEX TX EPISODE (IN MONTHS)'
   LOSCENSR= 'LOS CENSORED?'
   DURATTX = 'DURATION OF IN-TX NTEQ COVERAGE (IN MONT'
   DURAPTX = 'DURATION OF IN-TX NPAQ COVERAGE (IN MONT'
   DURAPDP = 'DURATION OF POST-DISCHARGE (IN MONTHS)'
   TFSCOMP = 'TREATMENT PROTOCOL COMPLETED'
   NRIQLTAR= 'LIFETIME ARRESTS AT NRIQ CONCORDANCE'
   NRIQDRUG= 'DRUG ARREST AT NRIQ CONCORDANCE'
   NPAQAR  = 'TOTAL NPAQ ARRESTS CONCORDANCE'
   FLDISP  = 'FIELD DISPOSITION'
   LABDISP = 'LAB DISPOSITION'
   CAN     = 'CANNABINOIDS'
   COC     = 'COCAINE'
   PCP     = 'PCP'
   OPI     = 'OPIATES'
   AMP     = 'AMPHETAMINES'
   BEN     = 'BENZODIAZOPINES'
   MET     = 'METHADONE'
   ALC     = 'ALCOHOL'
   RBEERVOL= 'OUNCES OF BEER DRUNK IN USUAL DAY'
   RWINEVOL= 'OUNCES OF WINE DRUNK IN USUAL DAY'
   RLIQUVOL= 'OUNCES OF LIQUOR DRUNK IN USUAL DAY'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (R2 <= -1) THEN R2 = .;
   IF (R5M1 <= -1) THEN R5M1 = .;
   IF (R15 <= -1) THEN R15 = .;
   IF (PRGMTYPE <= -1) THEN PRGMTYPE = .;
   IF (TRTMENT <= -1) THEN TRTMENT = .;
   IF (TRT2 <= -1) THEN TRT2 = .;
   IF (PRG2 <= -1) THEN PRG2 = .;
   IF (CELL <= -1) THEN CELL = .;
   IF (CELL2 <= -1) THEN CELL2 = .;
   IF (R17 <= -1) THEN R17 = .;
   IF (R19 <= -1) THEN R19 = .;
   IF (R21 <= -1) THEN R21 = .;
   IF (R24M1 <= -1) THEN R24M1 = .;
   IF (R24M2 <= -1) THEN R24M2 = .;
   IF (R24M3 <= -1) THEN R24M3 = .;
   IF (R24M4 <= -1) THEN R24M4 = .;
   IF (R24M6 <= -1) THEN R24M6 = .;
   IF (R24M7 <= -1) THEN R24M7 = .;
   IF (R24M8 <= -1) THEN R24M8 = .;
   IF (R24M9 <= -1) THEN R24M9 = .;
   IF (R24M10 <= -1) THEN R24M10 = .;
   IF (R24M11 <= -1) THEN R24M11 = .;
   IF (R24M12 <= -1) THEN R24M12 = .;
   IF (R24M13 <= -1) THEN R24M13 = .;
   IF (R24M14 <= -1) THEN R24M14 = .;
   IF (R24M15 <= -1) THEN R24M15 = .;
   IF (R24M16 <= -1) THEN R24M16 = .;
   IF (R24M17 <= -1) THEN R24M17 = .;
   IF (R24M18 <= -1) THEN R24M18 = .;
   IF (R24M19 <= -1) THEN R24M19 = .;
   IF (R24M21 <= -1) THEN R24M21 = .;
   IF (R24M22 <= -1) THEN R24M22 = .;
   IF (R25M1 <= -1) THEN R25M1 = .;
   IF (R25M2 <= -1) THEN R25M2 = .;
   IF (R25M3 <= -1) THEN R25M3 = .;
   IF (R25M4 <= -1) THEN R25M4 = .;
   IF (R27 <= -1) THEN R27 = .;
   IF (R29 <= -1) THEN R29 = .;
   IF (R34 <= -1) THEN R34 = .;
   IF (R35 <= -1) THEN R35 = .;
   IF (R39 <= -1) THEN R39 = .;
   IF (R41 <= -1) THEN R41 = .;
   IF (R42 <= -1) THEN R42 = .;
   IF (R44M1 <= -1) THEN R44M1 = .;
   IF (R46 <= -1) THEN R46 = .;
   IF (R47 <= -1) THEN R47 = .;
   IF (R50 <= -1) THEN R50 = .;
   IF (R53 <= -1) THEN R53 = .;
   IF (R55 <= -1) THEN R55 = .;
   IF (R56M1 <= -1) THEN R56M1 = .;
   IF (R56M2 <= -1) THEN R56M2 = .;
   IF (R56M3 <= -1) THEN R56M3 = .;
   IF (R56M4 <= -1) THEN R56M4 = .;
   IF (R56M5 <= -1) THEN R56M5 = .;
   IF (R56M6 <= -1) THEN R56M6 = .;
   IF (R56M8 <= -1) THEN R56M8 = .;
   IF (R56M9 <= -1) THEN R56M9 = .;
   IF (R58 <= -1) THEN R58 = .;
   IF (R61 <= -1) THEN R61 = .;
   IF (R62 <= -1) THEN R62 = .;
   IF (R64 <= -1) THEN R64 = .;
   IF (R67 <= -1) THEN R67 = .;
   IF (R71 <= -1) THEN R71 = .;
   IF (R72 <= -1) THEN R72 = .;
   IF (R74 <= -1) THEN R74 = .;
   IF (R76 <= -1) THEN R76 = .;
   IF (R77 <= -1) THEN R77 = .;
   IF (R79 <= -1) THEN R79 = .;
   IF (R84M1 <= -1) THEN R84M1 = .;
   IF (R84M2 <= -1) THEN R84M2 = .;
   IF (R84M3 <= -1) THEN R84M3 = .;
   IF (R84M4 <= -1) THEN R84M4 = .;
   IF (R84M5 <= -1) THEN R84M5 = .;
   IF (R84M6 <= -1) THEN R84M6 = .;
   IF (R84M7 <= -1) THEN R84M7 = .;
   IF (R84M8 <= -1) THEN R84M8 = .;
   IF (R84M10 <= -1) THEN R84M10 = .;
   IF (R84M12 <= -1) THEN R84M12 = .;
   IF (R90M1 <= -1) THEN R90M1 = .;
   IF (R90M2 <= -1) THEN R90M2 = .;
   IF (R90M3 <= -1) THEN R90M3 = .;
   IF (R90M4 <= -1) THEN R90M4 = .;
   IF (R90M5 <= -1) THEN R90M5 = .;
   IF (R90M6 <= -1) THEN R90M6 = .;
   IF (R90M7 <= -1) THEN R90M7 = .;
   IF (R90M8 <= -1) THEN R90M8 = .;
   IF (R90M9 <= -1) THEN R90M9 = .;
   IF (R90M10 <= -1) THEN R90M10 = .;
   IF (R90M11 <= -1) THEN R90M11 = .;
   IF (R91 = 4) THEN R91 = .;
   IF (R91 <= -1) THEN R91 = .;
   IF (R92 <= -1) THEN R92 = .;
   IF (R93 <= -1) THEN R93 = .;
   IF (R97 <= -1) THEN R97 = .;
   IF (R99 <= -1) THEN R99 = .;
   IF (R100M1 <= -1) THEN R100M1 = .;
   IF (R100M2 <= -1) THEN R100M2 = .;
   IF (R100M3 <= -1) THEN R100M3 = .;
   IF (R100M4 <= -1) THEN R100M4 = .;
   IF (R100M5 <= -1) THEN R100M5 = .;
   IF (R100M6 <= -1) THEN R100M6 = .;
   IF (R102 <= -1) THEN R102 = .;
   IF (R108A1 <= -1) THEN R108A1 = .;
   IF (R108A2 <= -1) THEN R108A2 = .;
   IF (R108A3 <= -1) THEN R108A3 = .;
   IF (R108A4 <= -1) THEN R108A4 = .;
   IF (R108A5 <= -1) THEN R108A5 = .;
   IF (R108A6 <= -1) THEN R108A6 = .;
   IF (R108A7 <= -1) THEN R108A7 = .;
   IF (R108A8 <= -1) THEN R108A8 = .;
   IF (R108A9 <= -1) THEN R108A9 = .;
   IF (R108A10 <= -1) THEN R108A10 = .;
   IF (R108A11 <= -1) THEN R108A11 = .;
   IF (R108A12 <= -1) THEN R108A12 = .;
   IF (R113M1 <= -1) THEN R113M1 = .;
   IF (R113M2 <= -1) THEN R113M2 = .;
   IF (R113M3 <= -1) THEN R113M3 = .;
   IF (R113M4 <= -1) THEN R113M4 = .;
   IF (R113M5 <= -1) THEN R113M5 = .;
   IF (R113M6 <= -1) THEN R113M6 = .;
   IF (R113M7 <= -1) THEN R113M7 = .;
   IF (R113M8 <= -1) THEN R113M8 = .;
   IF (R113M9 <= -1) THEN R113M9 = .;
   IF (R113M10 <= -1) THEN R113M10 = .;
   IF (R113M11 <= -1) THEN R113M11 = .;
   IF (R113M12 <= -1) THEN R113M12 = .;
   IF (R113M13 <= -1) THEN R113M13 = .;
   IF (R113M14 <= -1) THEN R113M14 = .;
   IF (R114M1 <= -1) THEN R114M1 = .;
   IF (R114M2 <= -1) THEN R114M2 = .;
   IF (R114M3 <= -1) THEN R114M3 = .;
   IF (R114M4 <= -1) THEN R114M4 = .;
   IF (R114M5 <= -1) THEN R114M5 = .;
   IF (R114M6 <= -1) THEN R114M6 = .;
   IF (R114M7 <= -1) THEN R114M7 = .;
   IF (R114M8 <= -1) THEN R114M8 = .;
   IF (R116A1 <= -1) THEN R116A1 = .;
   IF (R117A1 <= -1) THEN R117A1 = .;
   IF (R120A1 <= -1) THEN R120A1 = .;
   IF (R122A1 <= -1) THEN R122A1 = .;
   IF (R116A2 <= -1) THEN R116A2 = .;
   IF (R117A2 <= -1) THEN R117A2 = .;
   IF (R120A2 <= -1) THEN R120A2 = .;
   IF (R122A2 <= -1) THEN R122A2 = .;
   IF (R123A2 <= -1) THEN R123A2 = .;
   IF (R116A3 <= -1) THEN R116A3 = .;
   IF (R117A3 <= -1) THEN R117A3 = .;
   IF (R118A3 <= -1) THEN R118A3 = .;
   IF (R119A3 <= -1) THEN R119A3 = .;
   IF (R120A3 <= -1) THEN R120A3 = .;
   IF (R122A3 <= -1) THEN R122A3 = .;
   IF (R123A3 <= -1) THEN R123A3 = .;
   IF (R116A4 <= -1) THEN R116A4 = .;
   IF (R117A4 <= -1) THEN R117A4 = .;
   IF (R118A4 <= -1) THEN R118A4 = .;
   IF (R119A4 <= -1) THEN R119A4 = .;
   IF (R120A4 <= -1) THEN R120A4 = .;
   IF (R122A4 <= -1) THEN R122A4 = .;
   IF (R123A4 <= -1) THEN R123A4 = .;
   IF (R116A5 <= -1) THEN R116A5 = .;
   IF (R117A5 <= -1) THEN R117A5 = .;
   IF (R120A5 <= -1) THEN R120A5 = .;
   IF (R122A5 <= -1) THEN R122A5 = .;
   IF (R116A6 <= -1) THEN R116A6 = .;
   IF (R117A6 <= -1) THEN R117A6 = .;
   IF (R120A6 <= -1) THEN R120A6 = .;
   IF (R122A6 <= -1) THEN R122A6 = .;
   IF (R116A7 <= -1) THEN R116A7 = .;
   IF (R117A7 <= -1) THEN R117A7 = .;
   IF (R120A7 <= -1) THEN R120A7 = .;
   IF (R122A7 <= -1) THEN R122A7 = .;
   IF (R123A7 <= -1) THEN R123A7 = .;
   IF (R116A8 <= -1) THEN R116A8 = .;
   IF (R117A8 <= -1) THEN R117A8 = .;
   IF (R120A8 <= -1) THEN R120A8 = .;
   IF (R122A8 <= -1) THEN R122A8 = .;
   IF (R116A9 <= -1) THEN R116A9 = .;
   IF (R117A9 <= -1) THEN R117A9 = .;
   IF (R120A9 <= -1) THEN R120A9 = .;
   IF (R122A9 <= -1) THEN R122A9 = .;
   IF (R123A9 <= -1) THEN R123A9 = .;
   IF (R116A10 <= -1) THEN R116A10 = .;
   IF (R117A10 <= -1) THEN R117A10 = .;
   IF (R120A10 <= -1) THEN R120A10 = .;
   IF (R122A10 <= -1) THEN R122A10 = .;
   IF (R123A10 <= -1) THEN R123A10 = .;
   IF (R116A11 <= -1) THEN R116A11 = .;
   IF (R117A11 <= -1) THEN R117A11 = .;
   IF (R120A11 <= -1) THEN R120A11 = .;
   IF (R122A11 <= -1) THEN R122A11 = .;
   IF (R123A11 <= -1) THEN R123A11 = .;
   IF (R116A12 <= -1) THEN R116A12 = .;
   IF (R117A12 <= -1) THEN R117A12 = .;
   IF (R120A12 <= -1) THEN R120A12 = .;
   IF (R122A12 <= -1) THEN R122A12 = .;
   IF (R124 <= -1) THEN R124 = .;
   IF (R125 <= -1) THEN R125 = .;
   IF (R126 <= -1) THEN R126 = .;
   IF (R127 <= -1) THEN R127 = .;
   IF (R128 <= -1) THEN R128 = .;
   IF (R129 = 3) THEN R129 = .;
   IF (R129 <= -1) THEN R129 = .;
   IF (R130 <= -1) THEN R130 = .;
   IF (R131 <= -1) THEN R131 = .;
   IF (R132 <= -1) THEN R132 = .;
   IF (R133 <= -1) THEN R133 = .;
   IF (R135 <= -1) THEN R135 = .;
   IF (R136 <= -1) THEN R136 = .;
   IF (R137 <= -1) THEN R137 = .;
   IF (R138 <= -1) THEN R138 = .;
   IF (R139 <= -1) THEN R139 = .;
   IF (R140 <= -1) THEN R140 = .;
   IF (R142A1 <= -1) THEN R142A1 = .;
   IF (R143A1 <= -1) THEN R143A1 = .;
   IF (R144A1 <= -1) THEN R144A1 = .;
   IF (R147A1 <= -1) THEN R147A1 = .;
   IF (R142A2 <= -1) THEN R142A2 = .;
   IF (R143A2 <= -1) THEN R143A2 = .;
   IF (R144A2 <= -1) THEN R144A2 = .;
   IF (R147A2 <= -1) THEN R147A2 = .;
   IF (R142A3 <= -1) THEN R142A3 = .;
   IF (R143A3 <= -1) THEN R143A3 = .;
   IF (R144A3 <= -1) THEN R144A3 = .;
   IF (R155 <= -1) THEN R155 = .;
   IF (R156 <= -1) THEN R156 = .;
   IF (R157 <= -1) THEN R157 = .;
   IF (R159 <= -1) THEN R159 = .;
   IF (R160 <= -1) THEN R160 = .;
   IF (R161 <= -1) THEN R161 = .;
   IF (R162 <= -1) THEN R162 = .;
   IF (R171 <= -1) THEN R171 = .;
   IF (R172 <= -1) THEN R172 = .;
   IF (R173 <= -1) THEN R173 = .;
   IF (R174 <= -1) THEN R174 = .;
   IF (R175 <= -1) THEN R175 = .;
   IF (R176 <= -1) THEN R176 = .;
   IF (R177 <= -1) THEN R177 = .;
   IF (R178 <= -1) THEN R178 = .;
   IF (R179 <= -1) THEN R179 = .;
   IF (R182A1 <= -1) THEN R182A1 = .;
   IF (R184A1 <= -1) THEN R184A1 = .;
   IF (R185A1 <= -1) THEN R185A1 = .;
   IF (R182A2 <= -1) THEN R182A2 = .;
   IF (R184A2 <= -1) THEN R184A2 = .;
   IF (R185A2 <= -1) THEN R185A2 = .;
   IF (R182A3 <= -1) THEN R182A3 = .;
   IF (R184A3 <= -1) THEN R184A3 = .;
   IF (R185A3 <= -1) THEN R185A3 = .;
   IF (R182A4 <= -1) THEN R182A4 = .;
   IF (R185A4 <= -1) THEN R185A4 = .;
   IF (R182A5 <= -1) THEN R182A5 = .;
   IF (R185A5 <= -1) THEN R185A5 = .;
   IF (R182A6 <= -1) THEN R182A6 = .;
   IF (R185A6 <= -1) THEN R185A6 = .;
   IF (R182A7 <= -1) THEN R182A7 = .;
   IF (R185A7 <= -1) THEN R185A7 = .;
   IF (R182A8 <= -1) THEN R182A8 = .;
   IF (R185A8 <= -1) THEN R185A8 = .;
   IF (R182A9 <= -1) THEN R182A9 = .;
   IF (R185A9 <= -1) THEN R185A9 = .;
   IF (R187 <= -1) THEN R187 = .;
   IF (R189 <= -1) THEN R189 = .;
   IF (R190 <= -1) THEN R190 = .;
   IF (R191 <= -1) THEN R191 = .;
   IF (R192 <= -1) THEN R192 = .;
   IF (R193 <= -1) THEN R193 = .;
   IF (R194 <= -1) THEN R194 = .;
   IF (R195 <= -1) THEN R195 = .;
   IF (R198A1 <= -1) THEN R198A1 = .;
   IF (R198A2 <= -1) THEN R198A2 = .;
   IF (R198A3 <= -1) THEN R198A3 = .;
   IF (R198A4 <= -1) THEN R198A4 = .;
   IF (R198A5 <= -1) THEN R198A5 = .;
   IF (R200A1 <= -1) THEN R200A1 = .;
   IF (R202A1 <= -1) THEN R202A1 = .;
   IF (R200A2 <= -1) THEN R200A2 = .;
   IF (R202A2 <= -1) THEN R202A2 = .;
   IF (R200A3 <= -1) THEN R200A3 = .;
   IF (R202A3 <= -1) THEN R202A3 = .;
   IF (R200A4 <= -1) THEN R200A4 = .;
   IF (R202A4 <= -1) THEN R202A4 = .;
   IF (R200A5 <= -1) THEN R200A5 = .;
   IF (R202A5 <= -1) THEN R202A5 = .;
   IF (R203 <= -1) THEN R203 = .;
   IF (R204M1 <= -1) THEN R204M1 = .;
   IF (R204M2 <= -1) THEN R204M2 = .;
   IF (R204M3 <= -1) THEN R204M3 = .;
   IF (R204M4 <= -1) THEN R204M4 = .;
   IF (R204M5 <= -1) THEN R204M5 = .;
   IF (R204M6 <= -1) THEN R204M6 = .;
   IF (R205 <= -1) THEN R205 = .;
   IF (R206M1 <= -1) THEN R206M1 = .;
   IF (R206M2 <= -1) THEN R206M2 = .;
   IF (R206M3 <= -1) THEN R206M3 = .;
   IF (R206M4 <= -1) THEN R206M4 = .;
   IF (R206M5 <= -1) THEN R206M5 = .;
   IF (R206M6 <= -1) THEN R206M6 = .;
   IF (R207 <= -1) THEN R207 = .;
   IF (R208M1 <= -1) THEN R208M1 = .;
   IF (R208M2 <= -1) THEN R208M2 = .;
   IF (R211 <= -1) THEN R211 = .;
   IF (R212 <= -1) THEN R212 = .;
   IF (R213 <= -1) THEN R213 = .;
   IF (R214 <= -1) THEN R214 = .;
   IF (R216 <= -1) THEN R216 = .;
   IF (R218 <= -1) THEN R218 = .;
   IF (R219 <= -1) THEN R219 = .;
   IF (R220 <= -1) THEN R220 = .;
   IF (R221 = 5) THEN R221 = .;
   IF (R221 <= -1) THEN R221 = .;
   IF (R222 <= -1) THEN R222 = .;
   IF (R223 <= -1) THEN R223 = .;
   IF (R225 <= -1) THEN R225 = .;
   IF (R226 <= -1) THEN R226 = .;
   IF (R227 <= -1) THEN R227 = .;
   IF (R228 <= -1) THEN R228 = .;
   IF (R229 <= -1) THEN R229 = .;
   IF (R231 = 99) THEN R231 = .;
   IF (R231 <= -1) THEN R231 = .;
   IF (R232 = 99) THEN R232 = .;
   IF (R232 <= -1) THEN R232 = .;
   IF (R233 = 99) THEN R233 = .;
   IF (R233 <= -1) THEN R233 = .;
   IF (R234 <= -1) THEN R234 = .;
   IF (R236 <= -1) THEN R236 = .;
   IF (R237 <= -1) THEN R237 = .;
   IF (R238 <= -1) THEN R238 = .;
   IF (R239 <= -1) THEN R239 = .;
   IF (R240 <= -1) THEN R240 = .;
   IF (R241 <= -1) THEN R241 = .;
   IF (R242 <= -1) THEN R242 = .;
   IF (R244 <= -1) THEN R244 = .;
   IF (R245 <= -1) THEN R245 = .;
   IF (R246 <= -1) THEN R246 = .;
   IF (R247 <= -1) THEN R247 = .;
   IF (R248 <= -1) THEN R248 = .;
   IF (R250 <= -1) THEN R250 = .;
   IF (R251 <= -1) THEN R251 = .;
   IF (R253 <= -1) THEN R253 = .;
   IF (R255 <= -1) THEN R255 = .;
   IF (R256 <= -1) THEN R256 = .;
   IF (R258 <= -1) THEN R258 = .;
   IF (R259 = 999) THEN R259 = .;
   IF (R259 <= -1) THEN R259 = .;
   IF (R260 = 7) THEN R260 = .;
   IF (R260 <= -1) THEN R260 = .;
   IF (R262 = 5) THEN R262 = .;
   IF (R262 <= -1) THEN R262 = .;
   IF (R263 <= -1) THEN R263 = .;
   IF (R264 = 3) THEN R264 = .;
   IF (R264 <= -1) THEN R264 = .;
   IF (R270M1 <= -1) THEN R270M1 = .;
   IF (R270M2 <= -1) THEN R270M2 = .;
   IF (R270M3 <= -1) THEN R270M3 = .;
   IF (R270M4 <= -1) THEN R270M4 = .;
   IF (R271 <= -1) THEN R271 = .;
   IF (R272M1 <= -1) THEN R272M1 = .;
   IF (R272M2 <= -1) THEN R272M2 = .;
   IF (R272M3 <= -1) THEN R272M3 = .;
   IF (R273 <= -1) THEN R273 = .;
   IF (R274 <= -1) THEN R274 = .;
   IF (R275 <= -1) THEN R275 = .;
   IF (R276 <= -1) THEN R276 = .;
   IF (R277 <= -1) THEN R277 = .;
   IF (R278 <= -1) THEN R278 = .;
   IF (R279 <= -1) THEN R279 = .;
   IF (R280 <= -1) THEN R280 = .;
   IF (R281 <= -1) THEN R281 = .;
   IF (R282 <= -1) THEN R282 = .;
   IF (R287 <= -1) THEN R287 = .;
   IF (R288 <= -1) THEN R288 = .;
   IF (R289 <= -1) THEN R289 = .;
   IF (R290 <= -1) THEN R290 = .;
   IF (R291 <= -1) THEN R291 = .;
   IF (R292 <= -1) THEN R292 = .;
   IF (R293 <= -1) THEN R293 = .;
   IF (R294 <= -1) THEN R294 = .;
   IF (R295 <= -1) THEN R295 = .;
   IF (R296 = 3) THEN R296 = .;
   IF (R296 <= -1) THEN R296 = .;
   IF (R297 <= -1) THEN R297 = .;
   IF (R298 <= -1) THEN R298 = .;
   IF (R299 <= -1) THEN R299 = .;
   IF (R300 <= -1) THEN R300 = .;
   IF (R301 <= -1) THEN R301 = .;
   IF (R302 <= -1) THEN R302 = .;
   IF (R303 <= -1) THEN R303 = .;
   IF (R304 <= -1) THEN R304 = .;
   IF (R305 <= -1) THEN R305 = .;
   IF (R306 <= -1) THEN R306 = .;
   IF (R307 <= -1) THEN R307 = .;
   IF (R308 <= -1) THEN R308 = .;
   IF (R309 <= -1) THEN R309 = .;
   IF (R310 <= -1) THEN R310 = .;
   IF (R311 <= -1) THEN R311 = .;
   IF (R313A1 <= -1) THEN R313A1 = .;
   IF (R313A2 <= -1) THEN R313A2 = .;
   IF (R313A3 <= -1) THEN R313A3 = .;
   IF (R314 <= -1) THEN R314 = .;
   IF (R322 <= -1) THEN R322 = .;
   IF (R323 <= -1) THEN R323 = .;
   IF (R324 <= -1) THEN R324 = .;
   IF (R325 <= -1) THEN R325 = .;
   IF (R326 <= -1) THEN R326 = .;
   IF (R327 <= -1) THEN R327 = .;
   IF (R328 <= -1) THEN R328 = .;
   IF (R329 <= -1) THEN R329 = .;
   IF (R330 <= -1) THEN R330 = .;
   IF (R331 <= -1) THEN R331 = .;
   IF (R332 <= -1) THEN R332 = .;
   IF (R333 <= -1) THEN R333 = .;
   IF (R334 <= -1) THEN R334 = .;
   IF (R335 <= -1) THEN R335 = .;
   IF (R336 <= -1) THEN R336 = .;
   IF (R337 <= -1) THEN R337 = .;
   IF (R338 <= -1) THEN R338 = .;
   IF (R339 <= -1) THEN R339 = .;
   IF (R340 <= -1) THEN R340 = .;
   IF (R341 <= -1) THEN R341 = .;
   IF (R344A2 <= -1) THEN R344A2 = .;
   IF (R345A2 <= -1) THEN R345A2 = .;
   IF (R344A3 <= -1) THEN R344A3 = .;
   IF (R345A3 <= -1) THEN R345A3 = .;
   IF (R345A5 <= -1) THEN R345A5 = .;
   IF (R345A10 <= -1) THEN R345A10 = .;
   IF (R344A11 <= -1) THEN R344A11 = .;
   IF (R345A11 <= -1) THEN R345A11 = .;
   IF (R344A12 <= -1) THEN R344A12 = .;
   IF (R345A12 <= -1) THEN R345A12 = .;
   IF (R344A15 <= -1) THEN R344A15 = .;
   IF (R345A15 <= -1) THEN R345A15 = .;
   IF (R345A16 <= -1) THEN R345A16 = .;
   IF (R345A17 <= -1) THEN R345A17 = .;
   IF (R344A18 <= -1) THEN R344A18 = .;
   IF (R346 <= -1) THEN R346 = .;
   IF (R348A1 <= -1) THEN R348A1 = .;
   IF (R351A1 <= -1) THEN R351A1 = .;
   IF (R348A2 <= -1) THEN R348A2 = .;
   IF (R351A2 <= -1) THEN R351A2 = .;
   IF (R348A3 <= -1) THEN R348A3 = .;
   IF (R351A3 <= -1) THEN R351A3 = .;
   IF (R348A4 <= -1) THEN R348A4 = .;
   IF (R351A4 <= -1) THEN R351A4 = .;
   IF (R348A5 <= -1) THEN R348A5 = .;
   IF (R351A5 <= -1) THEN R351A5 = .;
   IF (R348A6 <= -1) THEN R348A6 = .;
   IF (R351A6 <= -1) THEN R351A6 = .;
   IF (R348A7 <= -1) THEN R348A7 = .;
   IF (R351A7 <= -1) THEN R351A7 = .;
   IF (R348A8 <= -1) THEN R348A8 = .;
   IF (R351A8 <= -1) THEN R351A8 = .;
   IF (R348A9 <= -1) THEN R348A9 = .;
   IF (R351A9 <= -1) THEN R351A9 = .;
   IF (R348A10 <= -1) THEN R348A10 = .;
   IF (R351A10 <= -1) THEN R351A10 = .;
   IF (R348A11 <= -1) THEN R348A11 = .;
   IF (R351A11 <= -1) THEN R351A11 = .;
   IF (R348A12 <= -1) THEN R348A12 = .;
   IF (R351A12 <= -1) THEN R351A12 = .;
   IF (R348A13 <= -1) THEN R348A13 = .;
   IF (R351A13 <= -1) THEN R351A13 = .;
   IF (R348A14 <= -1) THEN R348A14 = .;
   IF (R351A14 <= -1) THEN R351A14 = .;
   IF (R348A15 <= -1) THEN R348A15 = .;
   IF (R351A15 <= -1) THEN R351A15 = .;
   IF (R348A16 <= -1) THEN R348A16 = .;
   IF (R351A16 <= -1) THEN R351A16 = .;
   IF (R348A17 <= -1) THEN R348A17 = .;
   IF (R351A17 <= -1) THEN R351A17 = .;
   IF (R348A18 <= -1) THEN R348A18 = .;
   IF (R351A18 <= -1) THEN R351A18 = .;
   IF (R348A19 <= -1) THEN R348A19 = .;
   IF (R351A19 <= -1) THEN R351A19 = .;
   IF (R348A20 <= -1) THEN R348A20 = .;
   IF (R351A20 <= -1) THEN R351A20 = .;
   IF (R348A21 <= -1) THEN R348A21 = .;
   IF (R351A21 <= -1) THEN R351A21 = .;
   IF (R352 <= -1) THEN R352 = .;
   IF (R353 <= -1) THEN R353 = .;
   IF (R354 <= -1) THEN R354 = .;
   IF (R357 <= -1) THEN R357 = .;
   IF (R358 <= -1) THEN R358 = .;
   IF (R359 <= -1) THEN R359 = .;
   IF (R360 <= -1) THEN R360 = .;
   IF (R361 = 3) THEN R361 = .;
   IF (R361 <= -1) THEN R361 = .;
   IF (R362 = 3) THEN R362 = .;
   IF (R362 <= -1) THEN R362 = .;
   IF (R363 <= -1) THEN R363 = .;
   IF (R364 <= -1) THEN R364 = .;
   IF (R365 <= -1) THEN R365 = .;
   IF (R366 <= -1) THEN R366 = .;
   IF (R369 = 6) THEN R369 = .;
   IF (R369 <= -1) THEN R369 = .;
   IF (R371 <= -1) THEN R371 = .;
   IF (R372 <= -1) THEN R372 = .;
   IF (R373 <= -1) THEN R373 = .;
   IF (R375 <= -1) THEN R375 = .;
   IF (R377 <= -1) THEN R377 = .;
   IF (R378M1 <= -1) THEN R378M1 = .;
   IF (R378M2 <= -1) THEN R378M2 = .;
   IF (R378M3 <= -1) THEN R378M3 = .;
   IF (R378M4 <= -1) THEN R378M4 = .;
   IF (R378M5 <= -1) THEN R378M5 = .;
   IF (R378M6 <= -1) THEN R378M6 = .;
   IF (R378M7 <= -1) THEN R378M7 = .;
   IF (R378M8 <= -1) THEN R378M8 = .;
   IF (R378M9 <= -1) THEN R378M9 = .;
   IF (R378M10 <= -1) THEN R378M10 = .;
   IF (R378M11 <= -1) THEN R378M11 = .;
   IF (R378M12 <= -1) THEN R378M12 = .;
   IF (R378M13 <= -1) THEN R378M13 = .;
   IF (R378M14 <= -1) THEN R378M14 = .;
   IF (R378M15 <= -1) THEN R378M15 = .;
   IF (R378M16 <= -1) THEN R378M16 = .;
   IF (R378M17 <= -1) THEN R378M17 = .;
   IF (R379 <= -1) THEN R379 = .;
   IF (R380 <= -1) THEN R380 = .;
   IF (R381 <= -1) THEN R381 = .;
   IF (R384A1 <= -1) THEN R384A1 = .;
   IF (R385A1 <= -1) THEN R385A1 = .;
   IF (R388A1 <= -1) THEN R388A1 = .;
   IF (R389A1 <= -1) THEN R389A1 = .;
   IF (R389A2 <= -1) THEN R389A2 = .;
   IF (R391 <= -1) THEN R391 = .;
   IF (R392 = 3) THEN R392 = .;
   IF (R392 <= -1) THEN R392 = .;
   IF (R393 = 3) THEN R393 = .;
   IF (R393 <= -1) THEN R393 = .;
   IF (R397M1 = 3) THEN R397M1 = .;
   IF (R397M1 <= -1) THEN R397M1 = .;
   IF (R397M2 = 3) THEN R397M2 = .;
   IF (R397M2 <= -1) THEN R397M2 = .;
   IF (R397M3 = 3) THEN R397M3 = .;
   IF (R397M3 <= -1) THEN R397M3 = .;
   IF (R397M4 = 3) THEN R397M4 = .;
   IF (R397M4 <= -1) THEN R397M4 = .;
   IF (R397M5 = 3) THEN R397M5 = .;
   IF (R397M5 <= -1) THEN R397M5 = .;
   IF (R397M6 = 3) THEN R397M6 = .;
   IF (R397M6 <= -1) THEN R397M6 = .;
   IF (R397M7 = 3) THEN R397M7 = .;
   IF (R397M7 <= -1) THEN R397M7 = .;
   IF (R397M8 = 3) THEN R397M8 = .;
   IF (R397M8 <= -1) THEN R397M8 = .;
   IF (R397M9 = 3) THEN R397M9 = .;
   IF (R397M9 <= -1) THEN R397M9 = .;
   IF (R397M10 = 3) THEN R397M10 = .;
   IF (R397M10 <= -1) THEN R397M10 = .;
   IF (R397M11 = 3) THEN R397M11 = .;
   IF (R397M11 <= -1) THEN R397M11 = .;
   IF (R399 <= -1) THEN R399 = .;
   IF (R400 <= -1) THEN R400 = .;
   IF (R401 <= -1) THEN R401 = .;
   IF (R403 <= -1) THEN R403 = .;
   IF (R407M2 <= -1) THEN R407M2 = .;
   IF (R409 <= -1) THEN R409 = .;
   IF (R411 <= -1) THEN R411 = .;
   IF (R412 <= -1) THEN R412 = .;
   IF (R413 <= -1) THEN R413 = .;
   IF (R416A1 <= -1) THEN R416A1 = .;
   IF (R416A2 <= -1) THEN R416A2 = .;
   IF (R416A3 <= -1) THEN R416A3 = .;
   IF (R416A4 <= -1) THEN R416A4 = .;
   IF (R416A5 <= -1) THEN R416A5 = .;
   IF (R416A6 <= -1) THEN R416A6 = .;
   IF (R416A7 <= -1) THEN R416A7 = .;
   IF (R419M1 <= -1) THEN R419M1 = .;
   IF (R419M2 <= -1) THEN R419M2 = .;
   IF (R420 <= -1) THEN R420 = .;
   IF (R423 <= -1) THEN R423 = .;
   IF (R427A1 <= -1) THEN R427A1 = .;
   IF (R427A2 <= -1) THEN R427A2 = .;
   IF (R427A3 <= -1) THEN R427A3 = .;
   IF (R427A4 <= -1) THEN R427A4 = .;
   IF (R427A5 <= -1) THEN R427A5 = .;
   IF (R427A6 <= -1) THEN R427A6 = .;
   IF (R427A7 <= -1) THEN R427A7 = .;
   IF (R427A8 <= -1) THEN R427A8 = .;
   IF (R427A9 <= -1) THEN R427A9 = .;
   IF (R427A10 <= -1) THEN R427A10 = .;
   IF (R428 <= -1) THEN R428 = .;
   IF (R429 <= -1) THEN R429 = .;
   IF (R431 <= -1) THEN R431 = .;
   IF (R436A1 <= -1) THEN R436A1 = .;
   IF (R437A1 = 6) THEN R437A1 = .;
   IF (R437A1 <= -1) THEN R437A1 = .;
   IF (R436A2 <= -1) THEN R436A2 = .;
   IF (R437A2 = 6) THEN R437A2 = .;
   IF (R437A2 <= -1) THEN R437A2 = .;
   IF (R436A3 <= -1) THEN R436A3 = .;
   IF (R437A3 = 6) THEN R437A3 = .;
   IF (R437A3 <= -1) THEN R437A3 = .;
   IF (R436A4 <= -1) THEN R436A4 = .;
   IF (R437A4 = 6) THEN R437A4 = .;
   IF (R437A4 <= -1) THEN R437A4 = .;
   IF (R436A5 <= -1) THEN R436A5 = .;
   IF (R437A5 = 6) THEN R437A5 = .;
   IF (R437A5 <= -1) THEN R437A5 = .;
   IF (R439 <= -1) THEN R439 = .;
   IF (R440 <= -1) THEN R440 = .;
   IF (R441 <= -1) THEN R441 = .;
   IF (R442 <= -1) THEN R442 = .;
   IF (R443 <= -1) THEN R443 = .;
   IF (R444 <= -1) THEN R444 = .;
   IF (R445 <= -1) THEN R445 = .;
   IF (R447 <= -1) THEN R447 = .;
   IF (R448 <= -1) THEN R448 = .;
   IF (R449 <= -1) THEN R449 = .;
   IF (R450 <= -1) THEN R450 = .;
   IF (R451 <= -1) THEN R451 = .;
   IF (R452 <= -1) THEN R452 = .;
   IF (R454A1 <= -1) THEN R454A1 = .;
   IF (R456A1 <= -1) THEN R456A1 = .;
   IF (R455A2 <= -1) THEN R455A2 = .;
   IF (R456A2 <= -1) THEN R456A2 = .;
   IF (R455A3 <= -1) THEN R455A3 = .;
   IF (R456A3 <= -1) THEN R456A3 = .;
   IF (R457 <= -1) THEN R457 = .;
   IF (R458 <= -1) THEN R458 = .;
   IF (R459M1 <= -1) THEN R459M1 = .;
   IF (R459M2 <= -1) THEN R459M2 = .;
   IF (R459M3 <= -1) THEN R459M3 = .;
   IF (R459M4 <= -1) THEN R459M4 = .;
   IF (R462M1 <= -1) THEN R462M1 = .;
   IF (R462M4 <= -1) THEN R462M4 = .;
   IF (R462M5 <= -1) THEN R462M5 = .;
   IF (R463 <= -1) THEN R463 = .;
   IF (R464 <= -1) THEN R464 = .;
   IF (R465 <= -1) THEN R465 = .;
   IF (R466 <= -1) THEN R466 = .;
   IF (R467 = 3) THEN R467 = .;
   IF (R467 <= -1) THEN R467 = .;
   IF (R468 = 3) THEN R468 = .;
   IF (R468 <= -1) THEN R468 = .;
   IF (R469 = 3) THEN R469 = .;
   IF (R469 <= -1) THEN R469 = .;
   IF (R470 <= -1) THEN R470 = .;
   IF (R471 <= -1) THEN R471 = .;
   IF (R472 <= -1) THEN R472 = .;
   IF (R474 <= -1) THEN R474 = .;
   IF (RTOTANS <= -1) THEN RTOTANS = .;
   IF (RTOTREF <= -1) THEN RTOTREF = .;
   IF (RTOTDK <= -1) THEN RTOTDK = .;
   IF (AFDRUG1 <= -1) THEN AFDRUG1 = .;
   IF (AFDRUG2 <= -1) THEN AFDRUG2 = .;
   IF (QUEXSTAT <= -1) THEN QUEXSTAT = .;
   IF (BCSTAT <= -1) THEN BCSTAT = .;
   IF (URISTAT <= -1) THEN URISTAT = .;
   IF (LOS <= -1.00) THEN LOS = .;
   IF (LOSCENSR <= -1) THEN LOSCENSR = .;
   IF (DURATTX <= -1.00) THEN DURATTX = .;
   IF (DURAPTX <= -1) THEN DURAPTX = .;
   IF (DURAPDP <= -1.00) THEN DURAPDP = .;
   IF (TFSCOMP <= -1) THEN TFSCOMP = .;
   IF (NRIQLTAR <= -1) THEN NRIQLTAR = .;
   IF (NRIQDRUG <= -1) THEN NRIQDRUG = .;
   IF (NPAQAR <= -1) THEN NPAQAR = .;
   IF (FLDISP <= -1) THEN FLDISP = .;
   IF (LABDISP <= -1) THEN LABDISP = .;
   IF (CAN <= -1) THEN CAN = .;
   IF (COC <= -1) THEN COC = .;
   IF (PCP <= -1) THEN PCP = .;
   IF (OPI <= -1) THEN OPI = .;
   IF (AMP <= -1) THEN AMP = .;
   IF (BEN <= -1) THEN BEN = .;
   IF (MET <= -1) THEN MET = .;
   IF (ALC <= -1) THEN ALC = .;
   IF (RBEERVOL <= -1) THEN RBEERVOL = .;
   IF (RWINEVOL <= -1) THEN RWINEVOL = .;
   IF (RLIQUVOL <= -1) THEN RLIQUVOL = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT R2 r2ffffff. R5M1 r5m1ffff. R15 r15fffff.
         PRGMTYPE prgmtype. TRTMENT trtment. TRT2 trt2ffff.
         PRG2 prg2ffff. CELL cell. CELL2 cell2fff.
         R17 r17fffff. R19 r19fffff. R21 r21fffff.
         R24M1 r24m1fff. R24M2 r24m2fff. R24M3 r24m3fff.
         R24M4 r24m4fff. R24M6 r24m6fff. R24M7 r24m7fff.
         R24M8 r24m8fff. R24M9 r24m9fff. R24M10 r24m10ff.
         R24M11 r24m11ff. R24M12 r24m12ff. R24M13 r24m13ff.
         R24M14 r24m14ff. R24M15 r24m15ff. R24M16 r24m16ff.
         R24M17 r24m17ff. R24M18 r24m18ff. R24M19 r24m19ff.
         R24M21 r24m21ff. R24M22 r24m22ff. R25M1 r25m1fff.
         R25M2 r25m2fff. R25M3 r25m3fff. R25M4 r25m4fff.
         R27 r27fffff. R29 r29fffff. R34 r34fffff.
         R35 r35fffff. R39 r39fffff. R41 r41fffff.
         R42 r42fffff. R44M1 r44m1fff. R46 r46fffff.
         R47 r47fffff. R50 r50fffff. R53 r53fffff.
         R55 r55fffff. R56M1 r56m1fff. R56M2 r56m2fff.
         R56M3 r56m3fff. R56M4 r56m4fff. R56M5 r56m5fff.
         R56M6 r56m6fff. R56M8 r56m8fff. R56M9 r56m9fff.
         R58 r58fffff. R61 r61fffff. R62 r62fffff.
         R64 r64fffff. R67 r67fffff. R71 r71fffff.
         R72 r72fffff. R74 r74fffff. R76 r76fffff.
         R77 r77fffff. R84M1 r84m1fff. R84M2 r84m2fff.
         R84M3 r84m3fff. R84M4 r84m4fff. R84M5 r84m5fff.
         R84M6 r84m6fff. R84M7 r84m7fff. R84M8 r84m8fff.
         R84M10 r84m10ff. R84M12 r84m12ff. R90M1 r90m1fff.
         R90M2 r90m2fff. R90M3 r90m3fff. R90M4 r90m4fff.
         R90M5 r90m5fff. R90M6 r90m6fff. R90M7 r90m7fff.
         R90M8 r90m8fff. R90M9 r90m9fff. R90M10 r90m10ff.
         R90M11 r90m11ff. R91 r91fffff. R92 r92fffff.
         R93 r93fffff. R97 r97fffff. R99 r99fffff.
         R100M1 r100m1ff. R100M2 r100m2ff. R100M3 r100m3ff.
         R100M4 r100m4ff. R100M5 r100m5ff. R100M6 r100m6ff.
         R108A1 r108a1ff. R108A2 r108a2ff. R108A3 r108a3ff.
         R108A4 r108a4ff. R108A5 r108a5ff. R108A6 r108a6ff.
         R108A7 r108a7ff. R108A8 r108a8ff. R108A9 r108a9ff.
         R108A10 r108a10f. R108A11 r108a11f. R108A12 r108a12f.
         R113M1 r113m1ff. R113M2 r113m2ff. R113M3 r113m3ff.
         R113M4 r113m4ff. R113M5 r113m5ff. R113M6 r113m6ff.
         R113M7 r113m7ff. R113M8 r113m8ff. R113M9 r113m9ff.
         R113M10 r113m10f. R113M11 r113m11f. R113M12 r113m12f.
         R113M13 r113m13f. R113M14 r113m14f. R114M1 r114m1ff.
         R114M2 r114m2ff. R114M3 r114m3ff. R114M4 r114m4ff.
         R114M5 r114m5ff. R114M6 r114m6ff. R114M7 r114m7ff.
         R114M8 r114m8ff. R116A1 r116a1ff. R117A1 r117a1ff.
         R120A1 r120a1ff. R122A1 r122a1ff. R116A2 r116a2ff.
         R117A2 r117a2ff. R120A2 r120a2ff. R122A2 r122a2ff.
         R123A2 r123a2ff. R116A3 r116a3ff. R117A3 r117a3ff.
         R118A3 r118a3ff. R119A3 r119a3ff. R120A3 r120a3ff.
         R122A3 r122a3ff. R123A3 r123a3ff. R116A4 r116a4ff.
         R117A4 r117a4ff. R118A4 r118a4ff. R119A4 r119a4ff.
         R120A4 r120a4ff. R122A4 r122a4ff. R123A4 r123a4ff.
         R116A5 r116a5ff. R117A5 r117a5ff. R120A5 r120a5ff.
         R122A5 r122a5ff. R116A6 r116a6ff. R117A6 r117a6ff.
         R120A6 r120a6ff. R122A6 r122a6ff. R116A7 r116a7ff.
         R117A7 r117a7ff. R120A7 r120a7ff. R122A7 r122a7ff.
         R123A7 r123a7ff. R116A8 r116a8ff. R117A8 r117a8ff.
         R120A8 r120a8ff. R122A8 r122a8ff. R116A9 r116a9ff.
         R117A9 r117a9ff. R120A9 r120a9ff. R122A9 r122a9ff.
         R123A9 r123a9ff. R116A10 r116a10f. R117A10 r117a10f.
         R120A10 r120a10f. R122A10 r122a10f. R123A10 r123a10f.
         R116A11 r116a11f. R117A11 r117a11f. R120A11 r120a11f.
         R122A11 r122a11f. R123A11 r123a11f. R116A12 r116a12f.
         R117A12 r117a12f. R120A12 r120a12f. R122A12 r122a12f.
         R124 r124ffff. R125 r125ffff. R126 r126ffff.
         R127 r127ffff. R128 r128ffff. R129 r129ffff.
         R130 r130ffff. R131 r131ffff. R132 r132ffff.
         R133 r133ffff. R135 r135ffff. R136 r136ffff.
         R137 r137ffff. R138 r138ffff. R139 r139ffff.
         R140 r140ffff. R142A1 r142a1ff. R143A1 r143a1ff.
         R144A1 r144a1ff. R147A1 r147a1ff. R142A2 r142a2ff.
         R143A2 r143a2ff. R144A2 r144a2ff. R147A2 r147a2ff.
         R142A3 r142a3ff. R143A3 r143a3ff. R144A3 r144a3ff.
         R155 r155ffff. R156 r156ffff. R157 r157ffff.
         R159 r159ffff. R160 r160ffff. R161 r161ffff.
         R162 r162ffff. R171 r171ffff. R172 r172ffff.
         R173 r173ffff. R174 r174ffff. R175 r175ffff.
         R176 r176ffff. R177 r177ffff. R178 r178ffff.
         R179 r179ffff. R182A1 r182a1ff. R184A1 r184a1ff.
         R185A1 r185a1ff. R182A2 r182a2ff. R184A2 r184a2ff.
         R185A2 r185a2ff. R182A3 r182a3ff. R184A3 r184a3ff.
         R185A3 r185a3ff. R182A4 r182a4ff. R185A4 r185a4ff.
         R182A5 r182a5ff. R185A5 r185a5ff. R182A6 r182a6ff.
         R185A6 r185a6ff. R182A7 r182a7ff. R185A7 r185a7ff.
         R182A8 r182a8ff. R185A8 r185a8ff. R182A9 r182a9ff.
         R185A9 r185a9ff. R187 r187ffff. R189 r189ffff.
         R190 r190ffff. R191 r191ffff. R192 r192ffff.
         R193 r193ffff. R194 r194ffff. R195 r195ffff.
         R198A1 r198a1ff. R198A2 r198a2ff. R198A3 r198a3ff.
         R198A4 r198a4ff. R198A5 r198a5ff. R200A1 r200a1ff.
         R202A1 r202a1ff. R200A2 r200a2ff. R202A2 r202a2ff.
         R200A3 r200a3ff. R202A3 r202a3ff. R200A4 r200a4ff.
         R202A4 r202a4ff. R200A5 r200a5ff. R202A5 r202a5ff.
         R203 r203ffff. R204M1 r204m1ff. R204M2 r204m2ff.
         R204M3 r204m3ff. R204M4 r204m4ff. R204M5 r204m5ff.
         R204M6 r204m6ff. R205 r205ffff. R206M1 r206m1ff.
         R206M2 r206m2ff. R206M3 r206m3ff. R206M4 r206m4ff.
         R206M5 r206m5ff. R206M6 r206m6ff. R207 r207ffff.
         R208M1 r208m1ff. R208M2 r208m2ff. R211 r211ffff.
         R212 r212ffff. R213 r213ffff. R214 r214ffff.
         R216 r216ffff. R218 r218ffff. R219 r219ffff.
         R220 r220ffff. R221 r221ffff. R222 r222ffff.
         R223 r223ffff. R225 r225ffff. R226 r226ffff.
         R227 r227ffff. R228 r228ffff. R229 r229ffff.
         R231 r231ffff. R232 r232ffff. R233 r233ffff.
         R234 r234ffff. R236 r236ffff. R237 r237ffff.
         R238 r238ffff. R239 r239ffff. R240 r240ffff.
         R241 r241ffff. R242 r242ffff. R244 r244ffff.
         R245 r245ffff. R246 r246ffff. R247 r247ffff.
         R248 r248ffff. R250 r250ffff. R251 r251ffff.
         R255 r255ffff. R256 r256ffff. R258 r258ffff.
         R259 r259ffff. R260 r260ffff. R262 r262ffff.
         R263 r263ffff. R264 r264ffff. R270M1 r270m1ff.
         R270M2 r270m2ff. R270M3 r270m3ff. R270M4 r270m4ff.
         R271 r271ffff. R272M1 r272m1ff. R272M2 r272m2ff.
         R272M3 r272m3ff. R273 r273ffff. R274 r274ffff.
         R275 r275ffff. R276 r276ffff. R277 r277ffff.
         R278 r278ffff. R279 r279ffff. R280 r280ffff.
         R281 r281ffff. R282 r282ffff. R287 r287ffff.
         R288 r288ffff. R289 r289ffff. R290 r290ffff.
         R291 r291ffff. R292 r292ffff. R293 r293ffff.
         R294 r294ffff. R295 r295ffff. R296 r296ffff.
         R297 r297ffff. R298 r298ffff. R299 r299ffff.
         R300 r300ffff. R301 r301ffff. R302 r302ffff.
         R303 r303ffff. R304 r304ffff. R305 r305ffff.
         R306 r306ffff. R307 r307ffff. R308 r308ffff.
         R309 r309ffff. R310 r310ffff. R311 r311ffff.
         R313A1 r313a1ff. R313A2 r313a2ff. R313A3 r313a3ff.
         R322 r322ffff. R323 r323ffff. R324 r324ffff.
         R325 r325ffff. R326 r326ffff. R327 r327ffff.
         R328 r328ffff. R329 r329ffff. R330 r330ffff.
         R331 r331ffff. R332 r332ffff. R333 r333ffff.
         R334 r334ffff. R335 r335ffff. R336 r336ffff.
         R337 r337ffff. R338 r338ffff. R339 r339ffff.
         R340 r340ffff. R341 r341ffff. R344A2 r344a2ff.
         R345A2 r345a2ff. R344A3 r344a3ff. R345A3 r345a3ff.
         R345A5 r345a5ff. R345A10 r345a10f. R344A11 r344a11f.
         R345A11 r345a11f. R344A12 r344a12f. R345A12 r345a12f.
         R344A15 r344a15f. R345A15 r345a15f. R345A16 r345a16f.
         R345A17 r345a17f. R344A18 r344a18f. R346 r346ffff.
         R348A1 r348a1ff. R351A1 r351a1ff. R348A2 r348a2ff.
         R351A2 r351a2ff. R348A3 r348a3ff. R351A3 r351a3ff.
         R348A4 r348a4ff. R351A4 r351a4ff. R348A5 r348a5ff.
         R351A5 r351a5ff. R348A6 r348a6ff. R351A6 r351a6ff.
         R348A7 r348a7ff. R351A7 r351a7ff. R348A8 r348a8ff.
         R351A8 r351a8ff. R348A9 r348a9ff. R351A9 r351a9ff.
         R348A10 r348a10f. R351A10 r351a10f. R348A11 r348a11f.
         R351A11 r351a11f. R348A12 r348a12f. R351A12 r351a12f.
         R348A13 r348a13f. R351A13 r351a13f. R348A14 r348a14f.
         R351A14 r351a14f. R348A15 r348a15f. R351A15 r351a15f.
         R348A16 r348a16f. R351A16 r351a16f. R348A17 r348a17f.
         R351A17 r351a17f. R348A18 r348a18f. R351A18 r351a18f.
         R348A19 r348a19f. R351A19 r351a19f. R348A20 r348a20f.
         R351A20 r351a20f. R348A21 r348a21f. R351A21 r351a21f.
         R352 r352ffff. R353 r353ffff. R354 r354ffff.
         R357 r357ffff. R358 r358ffff. R359 r359ffff.
         R360 r360ffff. R361 r361ffff. R362 r362ffff.
         R363 r363ffff. R364 r364ffff. R365 r365ffff.
         R366 r366ffff. R369 r369ffff. R371 r371ffff.
         R372 r372ffff. R373 r373ffff. R377 r377ffff.
         R378M1 r378m1ff. R378M2 r378m2ff. R378M3 r378m3ff.
         R378M4 r378m4ff. R378M5 r378m5ff. R378M6 r378m6ff.
         R378M7 r378m7ff. R378M8 r378m8ff. R378M9 r378m9ff.
         R378M10 r378m10f. R378M11 r378m11f. R378M12 r378m12f.
         R378M13 r378m13f. R378M14 r378m14f. R378M15 r378m15f.
         R378M16 r378m16f. R378M17 r378m17f. R379 r379ffff.
         R380 r380ffff. R381 r381ffff. R384A1 r384a1ff.
         R385A1 r385a1ff. R388A1 r388a1ff. R389A1 r389a1ff.
         R389A2 r389a2ff. R391 r391ffff. R392 r392ffff.
         R393 r393ffff. R397M1 r397m1ff. R397M2 r397m2ff.
         R397M3 r397m3ff. R397M4 r397m4ff. R397M5 r397m5ff.
         R397M6 r397m6ff. R397M7 r397m7ff. R397M8 r397m8ff.
         R397M9 r397m9ff. R397M10 r397m10f. R397M11 r397m11f.
         R399 r399ffff. R400 r400ffff. R401 r401ffff.
         R403 r403ffff. R407M2 r407m2ff. R409 r409ffff.
         R411 r411ffff. R412 r412ffff. R413 r413ffff.
         R416A1 r416a1ff. R416A2 r416a2ff. R416A3 r416a3ff.
         R416A4 r416a4ff. R416A5 r416a5ff. R416A6 r416a6ff.
         R416A7 r416a7ff. R419M1 r419m1ff. R419M2 r419m2ff.
         R420 r420ffff. R423 r423ffff. R427A1 r427a1ff.
         R427A2 r427a2ff. R427A3 r427a3ff. R427A4 r427a4ff.
         R427A5 r427a5ff. R427A6 r427a6ff. R427A7 r427a7ff.
         R427A8 r427a8ff. R427A9 r427a9ff. R427A10 r427a10f.
         R428 r428ffff. R429 r429ffff. R431 r431ffff.
         R436A1 r436a1ff. R437A1 r437a1ff. R436A2 r436a2ff.
         R437A2 r437a2ff. R436A3 r436a3ff. R437A3 r437a3ff.
         R436A4 r436a4ff. R437A4 r437a4ff. R436A5 r436a5ff.
         R437A5 r437a5ff. R439 r439ffff. R440 r440ffff.
         R441 r441ffff. R442 r442ffff. R443 r443ffff.
         R444 r444ffff. R445 r445ffff. R447 r447ffff.
         R448 r448ffff. R449 r449ffff. R450 r450ffff.
         R451 r451ffff. R452 r452ffff. R454A1 r454a1ff.
         R456A1 r456a1ff. R455A2 r455a2ff. R456A2 r456a2ff.
         R455A3 r455a3ff. R456A3 r456a3ff. R457 r457ffff.
         R458 r458ffff. R459M1 r459m1ff. R459M2 r459m2ff.
         R459M3 r459m3ff. R459M4 r459m4ff. R462M1 r462m1ff.
         R462M4 r462m4ff. R462M5 r462m5ff. R463 r463ffff.
         R464 r464ffff. R465 r465ffff. R466 r466ffff.
         R467 r467ffff. R468 r468ffff. R469 r469ffff.
         R470 r470ffff. R471 r471ffff. R472 r472ffff.
         RTOTANS rtotans. RTOTREF rtotref. RTOTDK rtotdk.
         AFDRUG1 afdrug1f. AFDRUG2 afdrug2f. QUEXSTAT quexstat.
         BCSTAT bcstat. URISTAT uristat. LOSCENSR loscensr.
         DURATTX durattx. DURAPTX duraptx. DURAPDP durapdp.
         TFSCOMP tfscomp. NRIQLTAR nriqltar. NRIQDRUG nriqdrug.
         NPAQAR npaqar. FLDISP fldisp. LABDISP labdisp.
         CAN can. COC coc. PCP pcp.
         OPI opi. AMP amp. BEN ben.
         MET met. ALC alc. RBEERVOL rbeervol.
         RWINEVOL rwinevol. RLIQUVOL rliquvol.  ;
*/

RUN ;
